diff --git a/13.md b/13.md
new file mode 100644
index 000000000..6291e956f
--- /dev/null
+++ b/13.md
@@ -0,0 +1,3 @@
+- In the [[Flancia]] [[Pattern Language]], 13 means [[Bodhicitta]] and [[Right Conduct]].
+- [[Gloria a las maravillas del universo]] is 13 syllables in Spanish.
+- [[If you lose your Bodhicitta, sit down and find it]] is [[13 syllables]] in English.
diff --git a/311.md b/311.md
new file mode 100644
index 000000000..578dabf4c
--- /dev/null
+++ b/311.md
@@ -0,0 +1,3 @@
+- is it a prime, I wonder?
+ - https://anagora.org will tell me :D
+ -> [[prime/311]] means https://anagora.org/prime/311 by default
diff --git a/Adversarial Interoperability.md b/Adversarial Interoperability.md
new file mode 100644
index 000000000..200bcd334
--- /dev/null
+++ b/Adversarial Interoperability.md
@@ -0,0 +1,9 @@
+- I've been wanting to write more about [[adversarial interoperability]] for a while.
+- I've now filed it in [[55]] in the [[Flancia pattern language]] (I threw the number to choose).
+- In this node I plan to develop a short [[essay]]:
+
+# Adversarial Interoperability
+Or: [[The Two AIs]]
+Link: https://anagora/adversarial+interoperability
+
+Adversarial must be qualified and quantified immediately: what we set out to achieve is [[Digital Independence]] and increased public benefit, with [[Right Intention]]. If it seems to contradict (maybe temporarily) the alignment of corporations and be against their interests, so be it, because we need to do what is right for the future of [[humanity]] and our [[friends]].
diff --git a/Arthashastra.md b/Arthashastra.md
new file mode 100644
index 000000000..eefcf7e6b
--- /dev/null
+++ b/Arthashastra.md
@@ -0,0 +1 @@
+- #go https://en.wikipedia.org/wiki/Arthashastra
diff --git a/Avalokiteshvara.md b/Avalokiteshvara.md
new file mode 100644
index 000000000..470392f04
--- /dev/null
+++ b/Avalokiteshvara.md
@@ -0,0 +1,2 @@
+- a [[bodhisattva]].
+ - [[friend]].
diff --git a/Burup Maitreyas.md b/Burup Maitreyas.md
index ece5f177c..4baac8199 100644
--- a/Burup Maitreyas.md
+++ b/Burup Maitreyas.md
@@ -1,3 +1,6 @@
- [[391]] = [[17]] * [[23]]
- I did this calculation today and I found it pleasing.
- In this context Burup made me think of [[beaucoup]], which is a word my grandmother used
+ - #push [[Burup]]
+ - [[Tara]] Burup]]
+ - [[Taraburup]]
diff --git a/December Adventure 2023.md b/December Adventure 2023.md
new file mode 100644
index 000000000..d70b9d365
--- /dev/null
+++ b/December Adventure 2023.md
@@ -0,0 +1,9 @@
+- an [[adventure]].
+ - #go https://eli.li/december-adventure
+ - Do some coding on something that you care about, or that you just find interesting, every day of [[December 2023]].
+ - I'm in!
+ - My default project will be the [[Agora]] (are you surprised?) :)
+
+I started on December 1st, meaning [[2023-12-01]], after midnight -- I think it still counts as I hadn't gone to bed yet at 2AM when I started finally coding the fix for the Agora I had planned, and in UTC it was still the first :)
+
+I learnt about the challenge from [[bouncepaw]] ~ [[@bouncepaw]] in [[Flancia meet]] around 11 UTC on [[2023-12-02]] and I was immediately in.
diff --git a/Flancia Pattern Language.md b/Flancia Pattern Language.md
new file mode 100644
index 000000000..214c6fa46
--- /dev/null
+++ b/Flancia Pattern Language.md
@@ -0,0 +1,9 @@
+- [[Flancia]] can be seen as a [[book of patterns]] with [[108 chapters]].
+- [[0]] Bootstrap
+- [[1]] Flancia
+- [[2]] Fork
+- [[3]] Merge
+- [[5]] Light
+- [[6]] Flow
+- [[7]] Compassion
+- #pull [[17]]
diff --git a/Flancia doc.md b/Flancia doc.md
index 053bb180e..23b657257 100644
--- a/Flancia doc.md
+++ b/Flancia doc.md
@@ -1,8 +1,7 @@
- a [[document]].
- - …or four :)
- - you find in the [[Agora of Flancia]].
+ - …or several :)
+ - you find in the [[Agora of Flancia]].
- #2019 https://docs.google.com/document/d/1hKYrcScFTqggWhtlc-Ot3XQoWQmBFKXF/edit
- #2022 https://docs.google.com/document/d/1MxO0l9wDDWQdrutOVgdS6YO_TK9FH8C9/edit
- #go https://docs.google.com/document/d/1MxO0l9wDDWQdrutOVgdS6YO_TK9FH8C9/edit
- #stoa https://doc.anagora.org/flancia-doc
- - Publicly editable.
diff --git a/Flancia meet.md b/Flancia meet.md
index 76f325ad2..3de4971ea 100644
--- a/Flancia meet.md
+++ b/Flancia meet.md
@@ -1 +1,35 @@
- Hosted on [[jitsi meet]]: https://meet.jit.si/flancia-meet
+
+# [[2023-11-25]]
+
+- [[j0lms]]
+ - [[gwern]] on [[inclusionism]]
+ - [[mediawiki]]
+ - [[jimbo wales]]
+ - [[ayn rand]]
+ - [[frustración]] vs [[satisfacción]] de preferencias
+ - [[gramsci]]
+ - [[claudia goldin]] y [[human capital]]
+ - [[optimismo]] [[pesimismo]]
+ - [[maximalismo del optimismo]]
+ - [[leonor silvestri]]
+ - [[Qué hacer]] :)
+ - Crítica de [[Lenin]]
+ - [[milei]] vs [[maduro]]
+ - [[el estado mágico]]
+ - [[maldición holandesa]]
+ - [[marxian]] == [[marxiano]], [[marxianismo]]
+ - [[nobuo okishio]]
+ - graph on [[scale of cooperation]] / [[labor productivity]]
+ - [[1976]] [[The Theory of Accumulation]]
+ - [[marxian]] "la tasa de ganancia no baja como dice marx; sólo incrementa porque la matriz de commodities tiene sólo valores positivos"
+ - la conclusión de okiyo: la ganancia sólo sube
+ - [[spritz]] y sus patentes
+ - [[Arthashastra]]
+ - [[Bharat Ganarajya]] ~ [[India]]: https://en.wikipedia.org/wiki/India
+ - [[Qué hacer]] :)
+ - "Agenciar estructuras para-estatales de cooperación."
+ - [[Richard Wolff]]
+ - [[Deleuze]] [[Guattari]]
+ - [[anti natalidad]]
+ - [[poemas]] sumarizando con [[Bard]] y [[ChatGPT]]
diff --git a/Flancia, or the revolution against Moloch.md b/Flancia, or the revolution against Moloch.md
new file mode 100644
index 000000000..8cfc3ac52
--- /dev/null
+++ b/Flancia, or the revolution against Moloch.md
@@ -0,0 +1,7 @@
+What do you call a [[document]] that starts in many different ways, and ends in many different ways?
+
+Maybe a web page, if you follow [[links]]?
+
+
+
+- #pull [[revolution against Moloch]]
diff --git a/Gloria a las maravillas del universo.md b/Gloria a las maravillas del universo.md
new file mode 100644
index 000000000..53a42013e
--- /dev/null
+++ b/Gloria a las maravillas del universo.md
@@ -0,0 +1,2 @@
+- #push [[13]]
+ - [[13 sílabas]].
diff --git a/O oh O oh.md b/O oh O oh.md
new file mode 100644
index 000000000..83afe9fd5
--- /dev/null
+++ b/O oh O oh.md
@@ -0,0 +1,7 @@
+- [[5]]:
+-> [[Oh Lady Burup]]!
+ - Oh, [[Lady Burup]]
+ - [[Burup]]
+ - Buruuuuuup
+
+[[4]] + [[311]] hz
diff --git a/Open Letter to the Agora of Flancia.md b/Open Letter to the Agora of Flancia.md
new file mode 100644
index 000000000..c8bcc9a32
--- /dev/null
+++ b/Open Letter to the Agora of Flancia.md
@@ -0,0 +1,2 @@
+- an [[open letter]].
+ - #pull [[open letter to the agora]]
diff --git a/Richard Wolff.md b/Richard Wolff.md
new file mode 100644
index 000000000..6ee0fd541
--- /dev/null
+++ b/Richard Wolff.md
@@ -0,0 +1 @@
+- #go https://en.wikipedia.org/wiki/Richard_D._Wolff
diff --git a/Sinhalese.md b/Sinhalese.md
new file mode 100644
index 000000000..0eab48fe1
--- /dev/null
+++ b/Sinhalese.md
@@ -0,0 +1,4 @@
+- a [[people]].
+ - #pull [[Sinhalese Civilization]]
+
+
diff --git a/Sri Lanka.md b/Sri Lanka.md
new file mode 100644
index 000000000..ecb199b27
--- /dev/null
+++ b/Sri Lanka.md
@@ -0,0 +1,28 @@
+- #push [[trip to x]]
+ - #push [[three weeks in sri lanka]]
+ - #pull [[Colombo]] [[Kandy]] [[Anuradhapura]] [[Jaffna]] [[Ella]] [[Galle]] [[Sigirya]]
+ - [[Negombo]]
+- #go https://en.wikipedia.org/wiki/Sri_Lanka
+ - [[22 million]] people
+ - 70% [[Buddhist]]
+ - #pull [[Śrī Laṅkā]] [[Ceylon]] [[Eelam]] [[Taprobana]] [[Sarandib]]
+ - #pull [[Sinhalese]] [[Tamil]]
+ - #push [[Sri Lankan Civil War]] ~ https://en.wikipedia.org/wiki/Sri_Lankan_Civil_War is very recent ([[1983]]-[[2009]]
+ - A group tried to start an independent [[Tamil]] state.
+ - [[70000]] killed by [[2007]].
+ - [[Jaffna]] was the second largest city after [[Colombo]] before this conflict. Now it's the 12th largest (!).
+ - See also https://en.wikipedia.org/wiki/2019_Sri_Lanka_Easter_bombings by [[ISIS]]/[[ISIL]]
+ - [[Geography]]
+ - There used to be a natural land bridge to [[India]].
+ - > The "wet zone" and some of the windward slopes of the central highlands receive up to 2,500 millimetres (98.4 in) of rain each year, but the leeward slopes in the east and northeast receive little rain.
+ - There's [[elephants]] and [[leopards]].
+ - [[Gastronomy]]
+ - > Dishes include rice and curry, pittu, kiribath, wholemeal roti, string hoppers, wattalapam (a rich pudding of Malay origin made with coconut milk, jaggery, cashews, eggs, and spices including cinnamon and nutmeg), kottu, and appam.[368] Jackfruit may sometimes replace rice. Traditionally food is served on a plantain leaf or lotus leaf. Middle Eastern influences and practices are found in traditional Moor dishes, while Dutch and Portuguese influences are found with the island's Burgher community preserving their culture through traditional dishes such as lamprais (rice cooked in stock and baked in a banana leaf), breudher (Dutch holiday biscuit), and Bolo fiado (Portuguese-style layer cake).
+ - [[Culture]]
+ - > Ancient Sri Lanka is marked for its genius in [[hydraulic engineering]] and [[architecture]]
+ - > [[Sri Lankan Cinema]]
+ - [[Radio Ceylon]]
+ - The national sport is [[voleyball]] (!) but ~everybody's into cricket.
+ - [[Jaya Sri Maha Bodhi]] is the oldest planted tree in the world :)
+ - #beaches [[Bentota]] [[Unawatuna]]
+ - near [[Galle]]
diff --git a/Taraburup.md b/Taraburup.md
new file mode 100644
index 000000000..9e00ed5ba
--- /dev/null
+++ b/Taraburup.md
@@ -0,0 +1,9 @@
+Bella, muy [[bella]] [[Burup]]:
+ Bella, muy [[bella Burup]]!
+
+Bella, muy [[bella]] [[Burup]]:
+ [[Tara]] [[burup]],
+ [[Taraburup]]!
+
+Bella muy bella Burup,
+ [[Soha]]!
diff --git a/Vajrapani.md b/Vajrapani.md
new file mode 100644
index 000000000..4c9e3893f
--- /dev/null
+++ b/Vajrapani.md
@@ -0,0 +1,3 @@
+- a [[bodhisattva]].
+ - meaning "[[vajra]] in their hand"
+ - [[friend]]
diff --git a/Venceremos a Moloch.md b/Venceremos a Moloch.md
index 5c9cf38ab..5074129d2 100644
--- a/Venceremos a Moloch.md
+++ b/Venceremos a Moloch.md
@@ -1 +1,4 @@
- #pull [[meditations on moloch]] [[slay moloch]] [[save moloch]]
+- #push [[open letters]]
+ - [[Open Letter to the Agora of Flancia]]
+ - [[Open Letter to Google]]
diff --git a/What comes next.md b/What comes next.md
new file mode 100644
index 000000000..98d2261f4
--- /dev/null
+++ b/What comes next.md
@@ -0,0 +1 @@
+- #pull [[Flancia]]!
diff --git a/You see Moloch.md b/You see Moloch.md
new file mode 100644
index 000000000..199ef18f4
--- /dev/null
+++ b/You see Moloch.md
@@ -0,0 +1 @@
+I was [[37]] when I first [[saw Moloch]], although I had learnt about him previously in 2014 by reading [[Slate Star Codex]].
diff --git a/You will see me tonight.md b/You will see me tonight.md
new file mode 100644
index 000000000..54db3c83c
--- /dev/null
+++ b/You will see me tonight.md
@@ -0,0 +1,10 @@
+You will see me [[tonight]]:
+ into the darkness of light
+ (and its shadow),
+ into the [[light of night]]!
+
+For [[you]]:
+
+ - [[Tara]],
+ - [[Burup]],
+ - [[Taraburup]]!
diff --git a/agora slides 2023.md b/agora slides 2023.md
new file mode 100644
index 000000000..f2d7283fd
--- /dev/null
+++ b/agora slides 2023.md
@@ -0,0 +1,82 @@
+- a [[presentation]]
+ - #go https://docs.google.com/presentation/d/1MeYviCSxf9shZXmL8pWe6t4iR2spNqiOx0qs3swDsF8/edit#slide=id.p
+
+As of [[2023-09-10]], I am working on updating this with the [[Fellowship of the Link]] as its intended audience.
+
+What needs updating? Before diving into it, I would guess:
+
+1. Mention the diversity and interest that its community brings into the Commons. ~60/150 direct contributors as of the time of writing depending on how you count.
+2. Mention social media integration (Mastodon bot) and other venues for integration with the [[Fediverse]].
+3. Update screenshots (this will be a good opportunity to reconsider some of the changes introduced since 2021, likely).
+
+
+
+What else would need to be added?
+
+1. Maybe a mention of the Agora chapter in the [[personal knowledge graphs]] book.
+2. A mention of upcoming work:
+ - ActivityPub integration.
+ - SQLite/more stateful Agora.
+ - Oauth/other repository providers incoming.
+
+
+
+Wikilinks stand for the *intention to socially link*.
+
+- Counter-argument 1: two square brackets is a lot of brackets.
+ - Counter-counter-argument 1.1:
+
+Counter argument in general: on the value of [[building bridges]] and doing meaningful work in the [[Commons]].
+
+
+
+#Flancia is an entity of category [[protopoi]].
+
+The #Agora is an entity of category [[Commons]].
+
+
+
+(Here I took a detour to clean the kitchen and think of [[magnetic 3d printing]])
+
+
+
+You can currently join an Agora in two ways:
+
+- Keep a [[digital garden]] and contribute it to the Agora in question, as defined by you and your friends with loving-kindness :)
+- Follow @agora@botsin.space in the Fediverse and start using [[agora protocol]] in public, or within earshot of the bot.
+
+
+
+First services in the Commons:
+
+- Sharing.
+- Embedding.
+- Printing.
+- Format conversion.
+- Bridging,
+ - meaning porting across all useful and pro-social combinations of formats/mediums/networks.
+
+
+
+In the Agora your friends are the integration of your friendships over all participating social networks.
+
+
+
+I searched for [[markdown to google slides]] and I found https://github.com/googleworkspace/md2googleslides thanks precisely to the Agora.
+
+Love how the Agora is self-documenting ;)
+
+
+
+On the importance of debate and voting in the Agora, in the Fediverse.
+
+
+
+Node club.
+
+
+
+Open letters.
+
+
+
diff --git a/agora slides.md b/agora slides.md
index 728d22023..552e09909 100644
--- a/agora slides.md
+++ b/agora slides.md
@@ -1,5 +1,9 @@
# Agora Slides
-- [[go]] https://docs.google.com/presentation/d/10OWEuLriQpZzSJGq6vCSozZN4M34CNmEC1IrJxqk8xE/edit#slide=id.p
-- [[vera]] https://app.pitch.com/app/public/presentation/766c2727-e6f1-4ccf-b408-904b67bde5c9/5d419430-248b-4e81-a825-921e223c60dd
+This node or Agora location contains [[slide decks]] that have been produced about the Agora up to date as of [[2023]].
+
+- #go https://docs.google.com/presentation/d/1MeYviCSxf9shZXmL8pWe6t4iR2spNqiOx0qs3swDsF8/edit#slide=id.p
+- #2021 https://docs.google.com/presentation/d/10OWEuLriQpZzSJGq6vCSozZN4M34CNmEC1IrJxqk8xE/edit#slide=id.p
+- #vera https://app.pitch.com/app/public/presentation/766c2727-e6f1-4ccf-b408-904b67bde5c9/5d419430-248b-4e81-a825-921e223c60dd
+- #pull [[agora slides 2023]]
diff --git a/as we get to know each other.md b/as we get to know each other.md
new file mode 100644
index 000000000..c1209cff6
--- /dev/null
+++ b/as we get to know each other.md
@@ -0,0 +1,24 @@
+When you lose your [[bodhicitta]], sit down and find it!
+
+When you find your [[bodhicitta]], sit down and work!
+
+
+
+When you lose your [[bodhicitta]], sit down and find it!
+
+When you find your [[bodhicitta]], stand up and work!
+
+
+
+When you lose your [[bodhicitta]], stand up and find it!
+
+When you find your [[bodhicitta]], step up and work!
+
+
+When you lose your [[bodhicitta]], sit down and find it!
+
+When you find your [[bodhicitta]], lay down and rest!
+
+
+
+-> [[Venceremos a Moloch]]
diff --git a/assets/flanciaflag-xaos.png b/assets/flanciaflag-xaos.png
new file mode 100644
index 000000000..23e7501ef
Binary files /dev/null and b/assets/flanciaflag-xaos.png differ
diff --git a/avalokiteshvara.md b/avalokiteshvara.md
index 7f7374e7b..25d2d8302 100644
--- a/avalokiteshvara.md
+++ b/avalokiteshvara.md
@@ -16,3 +16,10 @@
- Avalokiteshvara!
- The fun comes from synchronizing while saying the first three words, and then choosing to synchronize or not on the saying of the name. For beginner players remembering the full name might prove difficult (it was for me at first).
- I like it as a game because [[Avalokiteshvara]] reminds me of a lot of things I deeply care about, and I find their name beautiful.
+- #push [[16]] syllables
+ - #push [[9]]
+ - Avalo, avalo, avalo!
+ - #push [[7]]
+ - Avalokiteshvara!
+
+ -
diff --git a/best japanese movies.md b/best japanese movies.md
new file mode 100644
index 000000000..afafe0568
--- /dev/null
+++ b/best japanese movies.md
@@ -0,0 +1 @@
+- #go https://www.highonfilms.com/best-japanese-movies/
diff --git a/bin/dice.py b/bin/dice.py
new file mode 100755
index 000000000..cabe8c217
--- /dev/null
+++ b/bin/dice.py
@@ -0,0 +1,53 @@
+#!/usr/bin/env python3
+#
+# https://click.palletsprojects.com/en/8.1.x/arguments/
+# https://click.palletsprojects.com/en/8.1.x/options/
+#
+# boilerplate shamelessly cloned from prime.py :).
+
+import click
+import math
+import random
+import sys
+
+class AgoraCmd(click.Command):
+ def format_help(self, ctx, formatter):
+ click.echo("""Usage:
+ - Visit anagora.org/dice to execute this file in the Agora of Flancia.
+ - Visit e.g. anagora.org/dice/17 to throw a 17-sided die, and others :)
+ - In general visit anagora.org/foo, anagora.org/foo/bar to execute e.g. from your garden.
+ """)
+
+ def __call__(self, *args, **kwargs):
+ try:
+ return super(AgoraCmd, self).__call__(
+ *args, standalone_mode=False, **kwargs)
+ except click.MissingParameter as exc:
+ exc.ctx = None
+ exc.show(file=sys.stdout)
+ click.echo()
+ try:
+ super(AgoraCmd, self).__call__(['--help'])
+ except SystemExit:
+ sys.exit(exc.exit_code)
+
+def rand(n):
+ proof = []
+ for i in range(2, n+1):
+ r = random.randint(1, i)
+ if i == 2:
+ proof.append(f"You throw a fair coin and it lands [[{bool(r-1) and 'heads' or 'tails'}]].")
+ else:
+ proof.append(f"You throw a die of [[{i}]] sides and it comes up [[{r}]].")
+
+ return "\n".join(reversed(proof))
+
+@click.command(cls=AgoraCmd)
+@click.argument('n', type=click.INT)
+def dice(n):
+ """A simple randomness generator, imitating those we know and love from R^4 :)."""
+ proof = rand(n)
+ click.echo(proof)
+
+if __name__ == '__main__':
+ dice()
diff --git a/bin/hex.py b/bin/hex.py
new file mode 100755
index 000000000..07f3f2c52
--- /dev/null
+++ b/bin/hex.py
@@ -0,0 +1,71 @@
+#!/usr/bin/env python3
+# https://click.palletsprojects.com/en/8.1.x/arguments/
+# https://click.palletsprojects.com/en/8.1.x/options/
+
+import click
+import math
+import sys
+
+# I'm not proud (I am a little bit?).
+PROOF = [] # :)
+
+class AgoraCmd(click.Command):
+ def format_help(self, ctx, formatter):
+ click.echo("""Usage:
+ - Visit anagora.org/primes to execute this file in the Agora of Flancia.
+ - Visit e.g. anagora.org/primes/17 to test if 17 is prime.
+ - In general visit anagora.org/foo, anagora.org/foo/bar to execute e.g. from your garden.
+ """)
+
+ def __call__(self, *args, **kwargs):
+ try:
+ return super(AgoraCmd, self).__call__(
+ *args, standalone_mode=False, **kwargs)
+ except click.MissingParameter as exc:
+ exc.ctx = None
+ exc.show(file=sys.stdout)
+ click.echo()
+ try:
+ super(AgoraCmd, self).__call__(['--help'])
+ except SystemExit:
+ sys.exit(exc.exit_code)
+
+@click.command(cls=AgoraCmd)
+@click.argument('n', type=click.INT)
+def hexnum(n, centered=True):
+ """Calculates the first n hex numbers just for fun :)"""
+
+ # Going through this from first principles (from memory/deducing this) for fun :)
+
+ # Why does the first list comprehension I wrote knowing it was wrong not work?
+ # Is it because of its complexity? Note I don't know the 'closed form' for hex numbers yet but I think it exists.
+ # To calculate them, I only know you need to add 6 more than after the previous number.
+ # But that can't be (trivially) expressed in a list comprehension.
+ #
+ # hexnums = [int(centered) + 6*n for n in range(0,n)]
+ # click.echo(f"These are not all hex numbers, but some are: {list(enumerate(hexnums))}")
+
+ # If we could skip one, then two, then three from the list above,
+ # we could exclude all non-hex-numbers.
+ # is there something in itertools that can do this for us?
+ # I don't think so. Maybe dropwhile with the right lambda?
+
+ # ...anyway, going at it old school.
+ # acc = int(centered)
+ # for row in range(0, n+1):
+ # acc += 6 * row
+ # click.echo(f"hex({row}) is {acc}.")
+
+ # ...and then https://oeis.org/A003215 to the rescue :)
+ # [[crystal ball sequence for hexagonal lattice]]: why does this work?
+ # -> https://en.wikipedia.org/wiki/Centered_hexagonal_number
+ # It is a cubic polynomial and Wikipedia shows how to convince yourself that it works.
+ # Beautiful :)
+ hexnums = [3*n*(n+1)+1 for n in range(0,n)]
+
+ for nth, hexnum in enumerate(hexnums):
+ click.echo(f"hex({nth+1}) is {hexnum}.")
+
+
+if __name__ == '__main__':
+ hexnum()
diff --git a/bin/primes.py b/bin/primes.py
new file mode 120000
index 000000000..8ddbbe4b1
--- /dev/null
+++ b/bin/primes.py
@@ -0,0 +1 @@
+prime.py
\ No newline at end of file
diff --git a/bin/prompt.py b/bin/prompt.py
new file mode 100755
index 000000000..918455230
--- /dev/null
+++ b/bin/prompt.py
@@ -0,0 +1,42 @@
+#!/usr/bin/env python3
+#
+# https://click.palletsprojects.com/en/8.1.x/arguments/
+# https://click.palletsprojects.com/en/8.1.x/options/
+#
+# boilerplate shamelessly cloned from prime.py :).
+
+import click
+import math
+import random
+import sys
+
+class AgoraCmd(click.Command):
+ def format_help(self, ctx, formatter):
+ click.echo("""Usage:
+ - Visit anagora.org/prompt to execute this file in the Agora of Flancia.
+ - Visit e.g. anagora.org/prompt/foo to prompt known models with 'foo'.
+ - In general visit anagora.org/foo, anagora.org/foo/bar to execute e.g. from your garden.
+ """)
+
+ def __call__(self, *args, **kwargs):
+ try:
+ return super(AgoraCmd, self).__call__(
+ *args, standalone_mode=False, **kwargs)
+ except click.MissingParameter as exc:
+ exc.ctx = None
+ exc.show(file=sys.stdout)
+ click.echo()
+ try:
+ super(AgoraCmd, self).__call__(['--help'])
+ except SystemExit:
+ sys.exit(exc.exit_code)
+
+@click.command(cls=AgoraCmd)
+@click.argument('s', type=click.STRING)
+def prompt(s):
+ """A simple utility to redirect to generation providers."""
+ gen = f"https://anagora.org/{s}"
+ click.echo(gen)
+
+if __name__ == '__main__':
+ prompt()
diff --git a/build maitreya.md b/build maitreya.md
index 7cf3e3649..b550d731c 100644
--- a/build maitreya.md
+++ b/build maitreya.md
@@ -1 +1,2 @@
-- #pull [[build bridges]]
+- #push [[open letter to maitreya]]
+ - #pull [[build bridges]]
diff --git a/carta abierta a milei.md b/carta abierta a milei.md
new file mode 100644
index 000000000..1a4c317e7
--- /dev/null
+++ b/carta abierta a milei.md
@@ -0,0 +1,3 @@
+- #push [[cartas abiertas]]
+ - Esta es una dedicada a [[Milei]], sin conocerlo, con buenas intenciones.
+
diff --git a/cartas abiertas.md b/cartas abiertas.md
new file mode 100644
index 000000000..ddca9e753
--- /dev/null
+++ b/cartas abiertas.md
@@ -0,0 +1 @@
+- #pull [[open letters]]
diff --git a/chatgpt playlist.md b/chatgpt playlist.md
new file mode 100644
index 000000000..d6e7fb653
--- /dev/null
+++ b/chatgpt playlist.md
@@ -0,0 +1,5 @@
+- #go https://music.youtube.com/playlist?list=PLtG4zc89ZUfHYcAFzLT-TGLK-3aUOUhhs&si=zzIRENY_GJ6CU7JT
+ - First track: OK
+ - Second track: not my thing I think
+ - Third: knew it, loved it from Amnesiac/Kid A days
+ - Fourth… well the list could be edited, I would swap this for a different Moby song. But it's an interesting start! And there's good songs in here, ideas.
diff --git a/commons.md b/commons.md
index 01f64a8c0..7cbb17b40 100644
--- a/commons.md
+++ b/commons.md
@@ -4,18 +4,18 @@
- The [[Agora of Flancia]] is a [[knowledge commons]].
- #go https://en.wikipedia.org/wiki/Commons
- In all matters pertaining the Commons I consider [[doubleloop]] ~ [[@neil]] the steward of this Agora.
- - The following picks from his notes below:
- - "beyond [[market]] and [[state]]"
- - I sometimes think of them as [[embedding]] and thus potentially [[regulating]] markets.
- - recommended [[free, fair and alive]], it's great. from his notes below:
- - [[commons]] are [[social organisms]], [[social systems]], [[social forms]]
- - a [[commons]] is not only about [[sharing]] but about creating [[systems]] that produce [[shareable things]]
- - they enable [[self organized problem solving]]
- - through social processes that build on the sharing of knowledge and physical resources
- - they are [[spaces]] that are born out of the impulse to [[help others]]
- - they bring together solutions to social, political and economic challenges into an integrated whole
- - [[pull]] [[commoning]] [[ontology]]
- - [[vera]] (from wiki below)
+ - The following picks from his notes below:
+ - "beyond [[market]] and [[state]]"
+ - I sometimes think of them as [[embedding]] and thus potentially [[regulating]] markets.
+ - recommended [[free, fair and alive]], it's great. from his notes below:
+ - [[commons]] are [[social organisms]], [[social systems]], [[social forms]]
+ - a [[commons]] is not only about [[sharing]] but about creating [[systems]] that produce [[shareable things]]
+ - they enable [[self organized problem solving]]
+ - through social processes that build on the sharing of knowledge and physical resources
+ - they are [[spaces]] that are born out of the impulse to [[help others]]
+ - they bring together solutions to social, political and economic challenges into an integrated whole
+ - [[pull]] [[commoning]] [[ontology]]
+ - [[vera]] (from wiki below)
- "The commons is the cultural and natural [[resources]] [[accessible to all]] members of a society, including natural materials such as air, water, and a habitable earth. These resources are held in common, [[not owned privately]]."
- [[pragmatix]]
- [[garrett hardin]]
diff --git a/corpus.md b/corpus.md
new file mode 100644
index 000000000..871069b55
--- /dev/null
+++ b/corpus.md
@@ -0,0 +1,6 @@
+- An [[essay]].
+ - On the importance of gathering a pro-social, rational good corpus.
+ - The [[Agora]] is a mechanism that tries to aid a community to gather an optimal corpus.
+
+As of [[2023]] ([[7]] * [[17]] * 17) the models trained on a 2021 corpus clearly demonstrate the potential of LL/generative models based on [[Transformers]] and Stable [[Diffusion]] as long as they are trained on a rich enough [[corpus]]. The fact that [[Chat GPT]], the most used widely available free text completion service, has a [[2021]] (43 * 47) cutoff date...
+
diff --git a/darius kazemi.md b/darius kazemi.md
new file mode 100644
index 000000000..c96052e56
--- /dev/null
+++ b/darius kazemi.md
@@ -0,0 +1,3 @@
+- a [[person]].
+ - [[friend]] (going by [[public view]] at least, or speaking in the Fediverse way, as of 2023.)
+ - #go https://runyourown.social/
diff --git a/december adventure.md b/december adventure.md
new file mode 100644
index 000000000..0cb22ff00
--- /dev/null
+++ b/december adventure.md
@@ -0,0 +1,7 @@
+- a [[thing]].
+ - an [[adventure]].
+ - #go https://eli.li/2022/12/9/december-adventure
+ - like [[advent of code]], but chiller.
+ - by [[eli]].
+ - [[bouncepaw]] told me about it.
+ - #pull [[december adventure 2023]] [[december 2023 adventure]]
diff --git a/dice.md b/dice.md
new file mode 100644
index 000000000..bf9b29ea6
--- /dev/null
+++ b/dice.md
@@ -0,0 +1 @@
+- You carry a [[set]] of [[dice]] in your [[bag of holding]].
diff --git a/document.md b/document.md
new file mode 100644
index 000000000..e18eb2aa8
--- /dev/null
+++ b/document.md
@@ -0,0 +1,2 @@
+- a [[thing]].
+ - #pull [[agora chapter]] [[flancia book]]
diff --git a/doing.md b/doing.md
new file mode 100644
index 000000000..597a42dfb
--- /dev/null
+++ b/doing.md
@@ -0,0 +1,2 @@
+- from [[flancia meet]] [[2023-12-02]]
+ - [ ] sign up for [[December Adventure 2023]] :)
diff --git a/el estado mágico.md b/el estado mágico.md
new file mode 100644
index 000000000..50973be0d
--- /dev/null
+++ b/el estado mágico.md
@@ -0,0 +1 @@
+- #go https://www.amazon.com/-/es/Fernando-Coronil-%C3%8Dmber/dp/9803543687
diff --git a/eli.md b/eli.md
new file mode 100644
index 000000000..24cf346e2
--- /dev/null
+++ b/eli.md
@@ -0,0 +1,4 @@
+- a [[person]].
+ - #go https://eli.li/about
+ - #pull [[eli oat]] [[oat]]
+ - started [[december adventure]]
diff --git a/español.md b/español.md
new file mode 100644
index 000000000..e08635789
--- /dev/null
+++ b/español.md
@@ -0,0 +1,7 @@
+- Mi idioma materno.
+
+Hola! Gracias por estar acá. Si encontraste este video en youtube o en otro repositorio de videos: bienenide! Espero que en este día (en el día en que encontrás esto) te esté yendo bien :)
+
+Escribo esto en [[2023-10-03]]. Qué fecha es por allá?
+
+Para contestar, podés visitar https://anagora.org/2023-10-03 y leer ese nodo, o visitar una [[Stoa]].
diff --git a/flancia book.md b/flancia book.md
index 352a02379..8317bfe3f 100644
--- a/flancia book.md
+++ b/flancia book.md
@@ -1,6 +1,4 @@
- a [[book]].
- A [[thing]] you find some day, free on the [[internet]].
- - Assembled from fragments found in https://flancia.org and https://anagora.org.
- - #go https://github.com/flancian/flancia
- - #git [[flancia/git]]
- - #pull [[flancia org]] [[flancia doc]]
+ - Assembled from fragments, like those found in https://flancia.org and https://anagora.org.
+ - #pull [[agora doc]] [[flancia doc]]
diff --git a/flancia doc.md b/flancia doc.md
new file mode 100644
index 000000000..3b51e22fc
--- /dev/null
+++ b/flancia doc.md
@@ -0,0 +1 @@
+- I have a [[Google Docs]] version of https://flancia.org. I thought several times of moving writing there, but I haven't solved the question of how to 'sync back' text to the site, if at all.
diff --git a/flancia meet.md b/flancia meet.md
index 45d592db8..7b1a432ca 100644
--- a/flancia meet.md
+++ b/flancia meet.md
@@ -1,5 +1,7 @@
- a [[meeting]].
- - #go https://meet.jit.si/flancia-meet
+ - #oldgo https://meet.jit.si/flancia-meet
+ - #go https://framatalk.org/flancia-meet
+ - #doc https://doc.anagora.org/flancia-meet?edit
- recurring, just show up if interested :) I attend often but not always.
- we take notes in the Stoa below or sometimes in the Agora at large (in [[journal]] entries).
- no [[fomo]], no [[stress]]!
diff --git a/flow state.md b/flow state.md
index 24fcb81c9..bed2196cb 100644
--- a/flow state.md
+++ b/flow state.md
@@ -1,3 +1,8 @@
- a [[podcast]].
- - unfortunately [[spotify]] exclusive.
- - #go https://ourflowstate.com
\ No newline at end of file
+ - unfortunately [[spotify]] exclusive...
+ - until... 2023?
+ - no longer!
+ - #go https://ourflowstate.com
+ - #soundcloud https://soundcloud.com/our_flow_state
+ - #mixcloud https://www.mixcloud.com/our_flow_state/
+ - #yt https://www.youtube.com/@ourflowstate
diff --git a/flow.md b/flow.md
index 4df7fa17a..faba06448 100644
--- a/flow.md
+++ b/flow.md
@@ -2,13 +2,14 @@
- a [[state]]
- [[mental state]] [[desirable]]
- - [[wp]] https://en.wikipedia.org/wiki/Flow_(psychology)
+ - #wp https://en.wikipedia.org/wiki/Flow_(psychology)
- As defined by [[Mihaly Csikszentmihalyi]] (I can never remember how to spell his name).
- "In positive psychology, a flow state, also known colloquially as being in the zone, is the mental state in which a person performing some activity is fully immersed in a feeling of energized focus, full involvement, and enjoyment in the process of the activity. In essence, flow is characterized by the complete absorption in what one does, and a resulting transformation in one's sense of time."
- a [[project]]
- by [[david-gelernter]] and [[eric freeman]]
- https://www.wsj.com/articles/the-future-of-the-internet-is-flow-1443796858
+- #pull [[flow state]]
I don't enter flow as often as I would like and that usually frustrates me; it's low key frustration but frustation nevertheless, and it builds up the longer it is sustained. It's like a part of my brain knows that we should get back to it, but life gets in the way; or, most often, I just procrastinate on triggering the right conditions.
-Sometimes I like to get into flow with a [[quick fix]].
\ No newline at end of file
+Sometimes I like to get into flow with a [[quick fix]].
diff --git a/framatalk.md b/framatalk.md
new file mode 100644
index 000000000..cb5da751c
--- /dev/null
+++ b/framatalk.md
@@ -0,0 +1,4 @@
+- a [[tool]].
+ - [[videoconferencing]]. [[jitsi]] based.
+ - #go https://framatalk.org/framatalk
+ - drops you straight into call [[framatalk]], beautiful.
diff --git a/friends.md b/friends.md
index eb5b3a9d2..e91d5b34c 100644
--- a/friends.md
+++ b/friends.md
@@ -1,4 +1,4 @@
-- I dedicate this [[agora]], and [[flancia]], to [[you]], my [[friend]]!
+- I dedicate this [[Agora]], and [[Flancia]], to [[you]], my [[friend]]!
- #pull [[eight pomodoros for the benefit of all beings]]
- a [[list]].
- #pull [[friend]]
@@ -6,17 +6,19 @@
- I assume all are [[well intentioned]] by [[default]].
- I like to think of [[flancia]] as an interactive book dedicated to my [[friends]].
- I sometimes say I'll [[do]] a [[things]], and then I [[write]] instead, because I try to write for [[you]].
- - #push [[books]]
- - #go https://flancia.org
- - I like to think of [[books]] as [[mirrors]] you can occasionally travel through.
- - [[portals]], [[leaps]].
- - See you on the other side, my [[friends]]!
- - I dedicate this site, with all its [[mistakes]], to you, for whatever it's worth.
- - [[In Flancia there is an Agora]]
- - #es [[En Flancia hay un Agora]]!
- - [[Per aspera ad astra]], or [[together to eternity]]
- - [[El pueblo unido jamás será vencido]] == [[The People United Will Never Be Defeated]]
- - [[In Flancia there is no poverty]] == [[En Flancia no hay pobreza]]
- - [[Juntos Venceremos a Moloch]].
- - [[En Flancia hay muchas luces]].
- - [[Iremos juntos hasta el fin de la noche]].
\ No newline at end of file
+ - [[books]]:
+ - [[flancia book]]:
+ - #go https://flancia.org
+ - I like to think of [[books]] as [[mirrors]] you can occasionally travel through.
+ - [[portals]], [[leaps]].
+ - See you on the other side, my [[friends]]!
+ - I dedicate this site, with all its [[mistakes]], to you, for whatever it's worth.
+ - [[Manifesto]]
+ - [[In Flancia there is an Agora]]
+ - #es [[En Flancia hay un Agora]]!
+ - [[Per aspera ad astra]], or [[together to eternity]]
+ - [[El pueblo unido jamás será vencido]] == [[The People United Will Never Be Defeated]]
+ - [[In Flancia there is no poverty]] == [[En Flancia no hay pobreza]]
+ - [[Juntos Venceremos a Moloch]].
+ - [[En Flancia hay muchas luces]].
+ - [[Iremos juntos hasta el fin de la noche]].
diff --git a/fuck it.md b/fuck it.md
new file mode 100644
index 000000000..bf8ce8908
--- /dev/null
+++ b/fuck it.md
@@ -0,0 +1 @@
+- #pull [[fuck the pain away]]
diff --git a/gloria.md b/gloria.md
new file mode 100644
index 000000000..96a9654c3
--- /dev/null
+++ b/gloria.md
@@ -0,0 +1,4 @@
+- #push [[16]]
+ - Gloria, gloria, gloria!
+ - #push [[13]]
+ - [[Gloria a las maravillas del universo]]!
diff --git a/heart sutra.md b/heart sutra.md
index 8a67cb4af..6456b6dc8 100644
--- a/heart sutra.md
+++ b/heart sutra.md
@@ -1,4 +1,45 @@
# heart sutra
-- [[gate gate paragate parasamgate bodhi svaha]]
+- #pull https://plumvillage.org/wp-content/uploads/2014/09/2014-Thich-Nhat-Hanh-New-Heart-Sutra-letter-cc.pdf
+- #push [[gate gate paragate parasamgate bodhi svaha]]
+- Adapter from https://plumvillage.org/about/thich-nhat-hanh/letters/thich-nhat-hanh-new-heart-sutra-translation#thays-letter, a work in progress (see also Mastodon post):
+
+
+[[Avalokiteshvara]]
+while practicing deeply
+in the [[insight that brings us to the other shore]],
+ discovered
+ that the [[five Skandhas]] are [[empty]],
+ and with this realization
+ overcame ill-being.
+
+[[Sariputra]]:
+this [[Body]] is empty
+and empty is this body.
+This body is none other than emptiness
+and emptiness is none other than this body.
+
+The same is true of [[Feelings]],
+ [[Perceptions]],
+ [[Mental Formations]],
+ and [[Consciousness]].
+
+
+
+Sariputra:
+all phenomena bear the mark of emptiness;
+their nature is that of:
+no birth no death,
+ no being no non-being
+ no defilement no purity,
+ no increasing no decreasing.
+
+That is why Emptiness,
+ Body,
+ Feelings,
+ Perceptions,
+ Mental Formations
+ and Consciousness
+ are not separate [[self entities]].
+
diff --git a/holacracy.md b/holacracy.md
index de5869b19..d4be5e2fb 100644
--- a/holacracy.md
+++ b/holacracy.md
@@ -1,3 +1,5 @@
# holacracy
-- [[go]] https://en.wikipedia.org/wiki/Holacracy
+- #wp https://en.wikipedia.org/wiki/Holacracy
+- #go https://www.holacracy.org/
+- #list https://www.holacracy.org/r/which-organizations-use-holacracy/
diff --git a/humanity.md b/humanity.md
new file mode 100644
index 000000000..5cc7460f0
--- /dev/null
+++ b/humanity.md
@@ -0,0 +1 @@
+- [[41]]!
diff --git a/inclusionism.md b/inclusionism.md
new file mode 100644
index 000000000..fe0d8afda
--- /dev/null
+++ b/inclusionism.md
@@ -0,0 +1,3 @@
+- an [[essay]].
+ - by [[gwern]].
+ - #go https://gwern.net/inclusionism
diff --git a/janet.md b/janet.md
new file mode 100644
index 000000000..d3a072735
--- /dev/null
+++ b/janet.md
@@ -0,0 +1 @@
+- #go https://www.youtube.com/watch?v=LXbYeJKcRf4
diff --git a/journal/2023-09-04.md b/journal/2023-09-04.md
index 327f78c20..a0e9f743f 100644
--- a/journal/2023-09-04.md
+++ b/journal/2023-09-04.md
@@ -6,4 +6,6 @@
- [[deep]]
- #push [[todo]]
- [[autopush]], finally?
-
+- trying out [[wlvncc]], which I will try to remember as [[WayLand VNC Client]], also for machine-to-machine connections -- so far I was only using it for [[portal]], the script that I use to have a recursive view into a computer I'm using.
+ - it works very well but it doesn't have 'raw keyboard mode', which I need to be able to forward [[sway]] events to the target host that is also running sway.
+ - commented on https://github.com/any1/wlvncc/issues/24
diff --git a/journal/2023-09-07.md b/journal/2023-09-07.md
new file mode 100644
index 000000000..591ed9aa7
--- /dev/null
+++ b/journal/2023-09-07.md
@@ -0,0 +1,9 @@
+- [[Flancia]]!
+ - significa que todo lo que escribo acá está en #Flancia por defecto :)
+- Flancia is a [[collection]] of [[computational environments]].
+- #push [[Agora 2023]]
+ - [[Agora priorities]] for the rest of [[2023]]:
+ - merging [[sqlite]]
+ - [[activitypub]]
+ - [[oauth]]
+ - [[votes]]
diff --git a/journal/2023-09-09.md b/journal/2023-09-09.md
new file mode 100644
index 000000000..2a22ace57
--- /dev/null
+++ b/journal/2023-09-09.md
@@ -0,0 +1,15 @@
+- [[Flancia]]!
+ - [[Flancia meet]] with [[j0lms]]
+ - [[prompting of creativity]]
+ - #push [[agora plan]]
+ - support for new formats:
+ - [[txt]]
+ - [[mp3]]
+ - #push [[kfaraday]]
+ - an [[artist]].
+ - #push [[2023-09-20]]
+ - [[fellowship of the link]] :)
+ - Working (playing with) the presentation I could ask the fellowship feedback on
+ - Forked [[agora slides]] (2021) into [[agora slides 2023]] today.
+ - wrote [[You will see me tonight]]
+ - [[Tara Burup]], [[Taraburup]] :)
diff --git a/journal/2023-09-10.md b/journal/2023-09-10.md
new file mode 100644
index 000000000..901ca0a51
--- /dev/null
+++ b/journal/2023-09-10.md
@@ -0,0 +1,21 @@
+- In the [[Flancia pattern language]], [[10]] stands for:
+ - [[2]] * [[5]], meaning for example [[fork your focus]]
+ - [[right view]] (10 .. 17 hold the eightfold path)
+ - [[may you be free from suffering]] (as it comes after [[9]])
+- [[Agora development]]
+ - Yesterday I pushed to anagora.org ("prod") after merging a few PRs, it was great.
+ - Apparently this broke topline search (redirecting to searching at e.g. Google), will now look into why and
+ - [x] fix it
+- #push [[Ursula K. Le Guin]]
+ - [[The Language of the Night]] https://en.wikipedia.org/wiki/The_Language_of_the_Night
+- [[trip to X]]
+- [[magnetic]] [[3d printing]]
+ - -> [[magnetic 4d printing]]
+- [[agora slides]]
+ - [[agora slides 2023]] :)
+ - enjoyed the process!
+ - I've wanted to add a 'WTF' button to the Agora of Flancia for some time, I think I may go ahead and base it around this node ;)
+ - thought of [[4k.agor.ai]], an Agora that could default to the dimensions in a full screen 4k monitor.
+ - embedding 2x2 iframes would result in the approximate 4-browser-tiles format that seems like a solid default for such a resolution.
+ - more generally of course this should be implemented as a reactive layout where display resolution (default) and users specify the tiling shape.
+ - [[darius kazemi]] [[server forking should be easy]] https://runyourown.social
diff --git a/journal/2023-09-11.md b/journal/2023-09-11.md
new file mode 100644
index 000000000..775bb7d79
--- /dev/null
+++ b/journal/2023-09-11.md
@@ -0,0 +1,7 @@
+- [[Flancia]]!
+- [[agora slides]]
+- #push [[Flancia
+- #push [[debate]]
+ - Imagine a public global debate about the crimes of [[Moloch]], and the ways to move forward.
+- #push [[liquid democracy]]
+ - Imagine calling elections in every nation-state currently recognized by the UN where a group of people think they could be useful. These meaning in addition to those called by the state in question as per custom up-to-date: put succinctly, imagine the citizens of the internet calling for open, transparent, fair, liquid-democracy-advancing elections in Russia, United States, China -- a priori without the authorization of the states in question, but with an intent to cooperate rationally with them.
diff --git a/journal/2023-09-15.md b/journal/2023-09-15.md
new file mode 100644
index 000000000..45046bd9d
--- /dev/null
+++ b/journal/2023-09-15.md
@@ -0,0 +1 @@
+- [[lcd soundsystem]]
diff --git a/journal/2023-09-17.md b/journal/2023-09-17.md
new file mode 100644
index 000000000..a4cb2ce60
--- /dev/null
+++ b/journal/2023-09-17.md
@@ -0,0 +1,18 @@
+- [[Flancia]]!
+ - In [[Flancia]] all weekend!
+ - [[53]]
+ - [[crema pastelera]]
+ - [[creme brulee]]
+ - [[crema catalana]]
+ - [[Flancia, or the revolution against Moloch]]
+ - [ ] agora development
+ - [x] flancia writing
+ - [ ] [[agora slides 2023]]
+ - [[commons]]
+ - [x] research [[Sri Lanka]]
+ - [ ] research [[Gosinga]]
+ - Which Gosinga, I wonder? I thought it would be one in Sri Lanka (reading this on [[2023-09-21]] but it doesn't seem to be the case.
+
+Loved the [[Majihima]] discourses on [[Heartwood]] (I already knew this), [[Cowherd]], [[Gosinga]].
+
+[[3149]] is an interesting number. It's not prime: it's [[47]] (we will defeat Moloch) * 67 (Bodhi, Bodhisattva).
diff --git a/journal/2023-09-18.md b/journal/2023-09-18.md
new file mode 100644
index 000000000..08a64969d
--- /dev/null
+++ b/journal/2023-09-18.md
@@ -0,0 +1,26 @@
+- [[18]] is [[right understanding]] in the [[flancia]] [[pattern language]].
+ - Flancia is in some ways a [[calendar]]. I usually revisit the Flancia Pattern language daily, considering the current date as my default focus.
+- [[drishtis]] ~ [[29]] might be particularly interesting as it is a list; 29 tends to remind me of items on which my focus is trained on by default in the running month.
+ - on this note [[7]] and [[17]] this month were beautiful as usual
+ - [[20]] ~ [[agora slides]] this month as I'll present it to [[fotl]] in whichever shape it is :)
+- At this point I decided to start writing in the Agora assuming I have [[autopush]] on, even though I haven't implemented it.
+ - It will work like this: if you [[wikilink]] or #tag once node [[autopush]] in a resource, the Agora will try to push blocks for you even without mentioning #push; so the following would result in [[poems]] getting a push of this node without further ado.
+- [[poems]]
+ - I wrote [[Agua]] again today on my paper notebook.
+ - [[Fork]]
+ - Fork
+ - Fork, fork!
+ - As we fork we'll [[merge]]!
+ - [[Merge]]
+ - Merge
+ - Merge, merge!
+ - As we merge we'll [[fork]]!
+ - [[Flow]]
+ - Flow
+ - Flow, flow!
+ - As we flow we'll do kindly!
+- Hello from [[paramita]] :)
+ - [[fork]]
+ - [[nostromo]] music
+ - [[paramita]] [[agora slides]]
+ - [[sila]] [[letters]]
diff --git a/journal/2023-09-20.md b/journal/2023-09-20.md
new file mode 100644
index 000000000..0951cc066
--- /dev/null
+++ b/journal/2023-09-20.md
@@ -0,0 +1,48 @@
+i also use avidemux for simple video editing.
+20:22
+Samuel Klein
+Samuel Klein says:love your naming scheme!
+Samuel Klein says:this diagram also suggests scale-free design [which is compelling; not privileging zoomed-in or zoomed-out parts of the whole]
+Samuel Klein says:++
+20:36
+PK
+Peter Kaminski
+Peter Kaminski says:Flask is a lightweight web application framework for Python
+Peter Kaminski says:
+https://flask.palletsprojects.com/
+
+20:41
+JM
+Jerry Michalski
+Jerry Michalski says:is that like agreeing on a hashtag?
+20:47
+Samuel Klein
+Samuel Klein says:One thing I'd like to see more easily is the list of repositories in your agora, and which ones have a node for a given wikilink
+Samuel Klein says:I have to run! This was great to see, worth tuning to a 15-min pitch
+Samuel Klein says:❤️ ❤️ ❤️
+21:01
+avatar
+Samuel Klein
+Samuel Klein says:oho my next meeting was moved back I have 15 min 😃
+21:02
+JM
+Jerry Michalski
+Jerry Michalski says:yay!
+Jerry Michalski says:it's a hypertext catfish!
+21:05
+Aram Zucker-Scharff
+Aram Zucker-Scharff says:I found this very useful! I have to drop
+21:07
+JM
+Jerry Michalski
+Jerry Michalski says:see you!
+21:07
+PK
+Peter Kaminski
+Peter Kaminski says:
+https://en.wikipedia.org/wiki/Glock_switch
+
+21:09
+avatar
+Samuel Klein
+Samuel Klein says:there's probably room a tool like "full auto-linker" that could look through your doc + its context, check your agora for entities that exist across the conjoined namespace, and autolinking concepts the first time they appear in your doc
diff --git a/journal/2023-09-21.md b/journal/2023-09-21.md
new file mode 100644
index 000000000..88d88d0af
--- /dev/null
+++ b/journal/2023-09-21.md
@@ -0,0 +1,19 @@
+ - [[Flancia, or the revolution against Moloch]]
+ - [x] [[work]]
+ - [ ] agora development
+ - [x] flancia writing
+ - [x] [[agora slides 2023]]
+ - presented yesterday to the [[fellowship of the link]] after some technical difficulties
+ - received very interesting feedback! I am very thankfull
+ - -> [[agora commons]] [[agora platform]]
+ - [ ] research [[Gosinga]]
+ - This + Sri Lanka produced no hits but led me to [[Anuradhapura]] somehow on my web search
+
+- #push [[las jaras]]
+
+De quién son [[las jaras]]?
+
+Están las de Maitreya,
+las de Tara,
+las de Avalokiteshvara!
+
diff --git a/journal/2023-09-23.md b/journal/2023-09-23.md
new file mode 100644
index 000000000..c78578f19
--- /dev/null
+++ b/journal/2023-09-23.md
@@ -0,0 +1,14 @@
+- [[Flancia]]!
+ - [[flancia meet]]
+ - Quiet but also nice :) Catching up with messages.
+- Yesterday we watched [[Demons in Paradise]] with [[AG]] -- about the civil war in [[Sri Lanka]]. Harrowing stuff.
+- What is the name of that nice Python CLI library again?
+ - [[click]]?
+- [[state of html]] survey seems like a great way to learn about lots of modern [[HTML]] features: https://survey.devographics.com/en-US/survey/state-of-html/2023/
+- #push [[spaces]]
+ - [[fork]]!
+ - fork, fork!
+ - as we merge we'll fork!
+ - [[nostromo]] music
+ - [[paramita]] [[revolution against Moloch]]
+ - [[sila]] [[letters]]
diff --git a/journal/2023-09-24.md b/journal/2023-09-24.md
new file mode 100644
index 000000000..d76961b80
--- /dev/null
+++ b/journal/2023-09-24.md
@@ -0,0 +1,14 @@
+- #push [[Flancia]]
+ - remember the importance of the [[corpus]].
+ - how it is gathered, how it is selected, how it is curated (gardened?) over time.
+ - [[Agora]]
+ - [[Agora development]]
+ - Working on [[prime]], [[executable nodes]] after a 10 month hiatus: I told myself I should go for something very free/open on this Sunday flowing :)
+ - [[Mycoverse]]
+ - [[space]]
+ - [[gloria]]
+ - [[avalokiteshvara]]
+ - [[trip to x]]
+ - [[japan]]
+ - [[best japanese movies]]
+ - [[sri lanka]]
diff --git a/journal/2023-09-25.md b/journal/2023-09-25.md
new file mode 100644
index 000000000..2b40a2928
--- /dev/null
+++ b/journal/2023-09-25.md
@@ -0,0 +1,4 @@
+- [[Flancia]]!
+ - [[work]]
+ - [[social coop]] [[twg]]
+ - [[omelas]]
diff --git a/journal/2023-09-26.md b/journal/2023-09-26.md
new file mode 100644
index 000000000..4f14121c4
--- /dev/null
+++ b/journal/2023-09-26.md
@@ -0,0 +1,6 @@
+- [[work]]
+ - [[ER-CH]]
+ - [[NTF]]
+- [[Flancia]]!
+ - [[agora development]]?
+- [[RAV]]
diff --git a/journal/2023-09-27.md b/journal/2023-09-27.md
new file mode 100644
index 000000000..886453886
--- /dev/null
+++ b/journal/2023-09-27.md
@@ -0,0 +1,9 @@
+- [[just do it]]
+- [[gone]]
+- [[yoga with x]]
+- [[fellowship of the link]] was great!
+ - note this node takes minutes to load, and that's sort of awesome
+ - because of current agora behavior every embed that opens, in the node itself and everything it pulls by default, grabs focus when it loads. the result is a bit like an automatic tour of our conversations over the previous many months.
+ - it is... Agora [[demo mode]] / [[autopilot]], as I dreamt it, implemented as a side effect of bugs!
+ - [[neobooks]]
+ - I discovered someone took amazing notes while I gave the presentation yesterday. It filled me with joy, such friends!
diff --git a/journal/2023-09-29.md b/journal/2023-09-29.md
new file mode 100644
index 000000000..aa9e55e1f
--- /dev/null
+++ b/journal/2023-09-29.md
@@ -0,0 +1,17 @@
+- [[29]] is [[drishti]] in the #Flancia [[Pattern Language]].
+- My hobby, sometimes: think about whether numbers are prime while laying down or sitting.
+ - Take [[209]] -- it is not prime.
+ - I find this one quite beautiful, this is how I got there:
+ - It is not multiple of two or five trivially.
+ - It is not a multiple of three as its digits don't add up to a multiple.
+ - It is not a multiple of 7 because 210 is (as 21 is 3 * 7) and it's too near.
+ - Consider the hypothesis that it is multiple of 11.
+ - 220 is a multiple of 11 because 22 is.
+ - 220 - 11 is 209.
+ - So 209 is a multiple of 11. What is the other factor?
+ - Consider the hypothesis that it is a multiple of 19.
+ - 19 * 10 is 190.
+ - 190 + 19 is 209 precisely, so it is a multiple.
+ - Therefore 209 is 11 * 19.
+ - [[1547]] is not prime; it is 7 * 13 * 17.
+ - I got to this one by whistling a 1547 tone, seeing it in [[spectroid]], then checking https://anagora.org/prime/1547 :)
diff --git a/journal/2023-09-30.md b/journal/2023-09-30.md
new file mode 100644
index 000000000..5ee15fd98
--- /dev/null
+++ b/journal/2023-09-30.md
@@ -0,0 +1,20 @@
+- [[Flancia]]!
+ - [[AG]] :)
+ - [[Japan]]
+ - [[tickets]] :)
+ - [[best japanese movies]]
+ - #push [[Taixu]] ~ died 19[[47]], [[57]] years old
+ - [[Pure Land]]
+ - [[Maitreya]]
+ - [[Inner Court]]
+ - [[Amitabha]] which I have occasionally written [[Amithaba]] :)
+ - Their Pure Land is [[Sukhavati]] or [[Land of Bliss]]
+ - Apparently was called [[Dharmakara]] as a [[Bodhisattva]]
+ - Although [[Avalokiteshvara]] and [[Vajrapani]] are their disciples
+ - [[Agora]]
+ - [[agora development]]
+ - [[zippies]]
+ - [[autopush]]
+ - [ ] [[executable subnodes]] needs cleanup (feature flag)
+ - [[movie]]
+ - [[Los Reyes del Mundo]] en [[Filmingo]]
diff --git a/journal/2023-10-01.md b/journal/2023-10-01.md
new file mode 100644
index 000000000..79da49006
--- /dev/null
+++ b/journal/2023-10-01.md
@@ -0,0 +1,30 @@
+- [[Flancia]]!
+ - Today is also [[31]] of [[September]] in a way, just as yesterday was the [[0]] of [[October]] :)
+ - [[Pure Land]]
+ - [[Maitreya]]
+ - [[Inner Court]]
+ - [[Amitabha]] which I have occasionally written [[Amithaba]] :)
+ - Their Pure Land is [[Sukhavati]] or [[Land of Bliss]]
+ - Apparently was called [[Dharmakara]] as a [[Bodhisattva]]
+ - Although [[Avalokiteshvara]] and [[Vajrapani]] are their disciples
+ - [[Agora]]
+ - [[agora development]]
+ - [ ] [[zippies]]
+ - [ ] maybe move stoas back down? unsure. this might be an alternative to making zippies work.
+ - [ ] [[autopush]]
+ - [ ] take a look
+ - [ ] update agorai
+ - [x] [[executable subnodes]] needs cleanup (feature flag)
+ - [x] flip it on for anagora.org
+ - #push [[Open Letters]]
+ - the [[Agora]] is a repository of open letters:
+ - [[Taixu]]
+ - do I need to start it? or perhaps it's the [[Open Letter to the Agora of Flancia]]?
+ - [[Google]]
+ - [[Open letter to Google]]
+ - [[M]]
+ - [[Open letter to Maitreya]]
+ - [[Open letter to Mara]]
+ - [[Open letter to Moloch]]
+ - [[Open letter to Musk]]
+ - [[Carta abierta a Milei]]
diff --git a/journal/2023-10-02.md b/journal/2023-10-02.md
new file mode 100644
index 000000000..a5524dd9d
--- /dev/null
+++ b/journal/2023-10-02.md
@@ -0,0 +1,3 @@
+- [[uuid]] [[v7]] looks cool
+- [[work]]
+- [[Flancia]]
diff --git a/journal/2023-10-03.md b/journal/2023-10-03.md
new file mode 100644
index 000000000..bfc3fd046
--- /dev/null
+++ b/journal/2023-10-03.md
@@ -0,0 +1,28 @@
+- [[work]]
+ - meetings with [[er-ch]]
+ - [[consultation doc]]
+ - [[proposal]]
+- [[flancia]]!
+ - I've been thinking of [[flancia home]] in the context of [[mohammed]]
+ - [[37]]
+ - [[bodhi]]
+
+[[Imaginate un mundo sin latencia]] me dije, habiendo solucionado los problemas de conectividad bluetooth en [[nostromo]] :)
+
+A veces extraño el [[español]] como idioma.
+
+
+- #push [[youtube]]
+ - the uploading experience even on studio.youtube.com leaves me unsatisfied :)
+ - it is slow, you need to perform a multitude of clicks to get to publish something
+ - friction should be much lower than this!
+
+Mientras escribo esto, estoy escuchando [[hola frank]] de [[sumo]] :)
+
+- Next I will work on a [[proposal]] within the context of my work in the [[er-ch]].
+- And on my personal computer I will start work on [[x]] as the evening progresses :)
+
+Let us pray, dice Luca Prodan :)
+
+- Four hours later, I'm back here after three hours of work and then dinner+yoga.
+- [[janet]] made me laugh: https://www.youtube.com/watch?v=LXbYeJKcRf4
diff --git a/journal/2023-10-04.md b/journal/2023-10-04.md
new file mode 100644
index 000000000..bd407bb85
--- /dev/null
+++ b/journal/2023-10-04.md
@@ -0,0 +1,5 @@
+- [[work]]
+ - [[er-ch]]
+ - meetings
+- [[Flancia]]
+ - [[Zürich Film Festival]] with [[AG]] :)
diff --git a/journal/2023-10-05.md b/journal/2023-10-05.md
new file mode 100644
index 000000000..67c2e925e
--- /dev/null
+++ b/journal/2023-10-05.md
@@ -0,0 +1,8 @@
+- today is [[5]] October
+ - threw [[27]] which is [[loving kindness]], [[merge and keep merging]], and [[taixu]] in September,
+- [[work]]
+- [[flancia]]
+ - [[AG]]
+ - reunited with my [[Lady Burup]]
+
+Discussed divorce with [[L]], we've been separated for around 1.4 years. Things are going well and I wish us both happiness!
diff --git a/journal/2023-10-06.md b/journal/2023-10-06.md
new file mode 100644
index 000000000..f79e9ae88
--- /dev/null
+++ b/journal/2023-10-06.md
@@ -0,0 +1,3 @@
+- [[6]] ~ [[flow]]
+- [[open letters]] ~ [[59]]
+
diff --git a/journal/2023-10-07.md b/journal/2023-10-07.md
new file mode 100644
index 000000000..1699c6e7c
--- /dev/null
+++ b/journal/2023-10-07.md
@@ -0,0 +1,16 @@
+- [[flancia]]!
+ - [[flancia meet]]
+ - #push [[telescopes]] :)
+ - [[refractor]] vs [[reflector]]
+ - [[reflectors]] require [[collimation]] but are overall more capable
+ - [[reflectors]]
+ - [[orion skyquest xt6]]
+ - hmm, [[orion]] seems to be [[employee owned]]?
+ - [[celestron starsense explorer]] is available on [[galaxus]]
+- on other definitions of [[pull]] and [[push]]: https://kellanem.com/notes/push-and-pull
+- #push [[open letters]]
+ - [[17]] [[maitreya]]
+ - [[71]] [[musk]]
+ - [[97]] [[alphabet]], or should it be [[98]] as [[google]] was founded then?
+ - I finally wrote down the list for [[October 2023]] on paper (a post it I'll keep in one of my desks) and above
+- [[carta abierta a milei]] se suma a la competición (?)
diff --git a/journal/2023-10-09.md b/journal/2023-10-09.md
new file mode 100644
index 000000000..3394a0512
--- /dev/null
+++ b/journal/2023-10-09.md
@@ -0,0 +1,5 @@
+- [[flancia]]!
+ - [[work]]
+ - [[er-ch]] gets intense sometimes
+ - still it's a privilege to represent [[zooglers]] and to some extent [[googlers]], meaning my fellow employees
+ - [[aldhari]]
diff --git a/journal/2023-10-11.md b/journal/2023-10-11.md
new file mode 100644
index 000000000..a7951c0ae
--- /dev/null
+++ b/journal/2023-10-11.md
@@ -0,0 +1,4 @@
+- [[flancia]]!
+ - [[work]]
+ - [[fellowship of the link]]
+ - [[public ai]]
diff --git a/journal/2023-10-14.md b/journal/2023-10-14.md
new file mode 100644
index 000000000..2cc5f0adc
--- /dev/null
+++ b/journal/2023-10-14.md
@@ -0,0 +1,24 @@
+- Welcome to the Agora of Flancia!
+ - Today and every day.
+
+Today is [[14 October 2023]] and I am glad you are here with me.
+
+It has been ages since I've in Flancia, sometimes it feels, even as time is varying.
+
+
+
+Here is what I call a poem: [[trees]].
+
+
+
+This weekend I intend to advance what I call [[open letters]]: documents addressed to groups, openly published even as they are being written.
+
+
+
+As of 21:45 CET I did some 'day job' stuff (having chosen it) and started a proposal (open letter, as per the above) that I had on my todo list.
+
+Now switching to [[paramita]], planning to continue on related topics but in the [[commons]].
+
+
+
+Today we bought the tickets to and from [[Sri Lanka]], happy about it!
diff --git a/journal/2023-10-15.md b/journal/2023-10-15.md
new file mode 100644
index 000000000..ca3ce4054
--- /dev/null
+++ b/journal/2023-10-15.md
@@ -0,0 +1,3 @@
+- [[Flancia]]!
+ - Thank you [[AG]].
+ - Thank you to all my [[friends]]!
diff --git a/journal/2023-10-16.md b/journal/2023-10-16.md
new file mode 100644
index 000000000..d83a0a438
--- /dev/null
+++ b/journal/2023-10-16.md
@@ -0,0 +1,6 @@
+- [[Flancia]]!
+ - I woke up with a cold, have the sniffles hard; I [[worked]] from home and took it easy -- no meetings after 15:30, tried to rest. Tested negative for Covid though!
+ - Last light in the balcony looking southwest, cold day but beautiful.
+ - [[AG]]
+ - [[Lady Burup]]
+ - I thought of [[Tara]].
diff --git a/journal/2023-10-17.md b/journal/2023-10-17.md
new file mode 100644
index 000000000..6b815c2f7
--- /dev/null
+++ b/journal/2023-10-17.md
@@ -0,0 +1,15 @@
+- [[Flancia]]!
+ - [[work]]
+ - I still have a cold but it was slightly better.
+ - I checked with the [[dentist]] and they didn't mind (I tested negative for Covid yesterday), so I went ahead and I'm happy with the results!
+ - [[Agora]]!
+ - I thought of implementing ! as a short for #push, meaning that anything wikilinked and "strongly asserted" behaves the same as push: the following blocks are transcluded in the destination.
+ - [[open letters]]!
+ - [[open letter to musk]]
+ - [[carta abierta a milei]]
+ - [[hex]] numbers :)
+ - I calculated [[397]] as the 11th hex number, but if you define them naturally (with one ball yielding the first hex number, not the zeroeth) it would be [[469]]
+ - Still it was fun to do it in my head :) it took 15'-25' while I was doing yoga.
+ - I came away with a renewed appreciation of hex numbers.
+ - I then decided to code an hex [[number]] producer :)
+ - https://github.com/flancian/garden/commit/3d4e608b6cb78aa55b039cd6ce0716e9d8275e9d just for fun.
diff --git a/journal/2023-10-19.md b/journal/2023-10-19.md
new file mode 100644
index 000000000..b2cb94a5b
--- /dev/null
+++ b/journal/2023-10-19.md
@@ -0,0 +1,9 @@
+- [[Flancia]]!
+- [[work]]
+ - was tough
+ - it started well with a reassuring conversation with a mentor, but the day ended with more conflict again in the employee representation group.
+ - the sub-group within the group I am in -- I find really draining; it is one of the most difficult groups I've been in, in part because of a personality mismatch between myself and the rest of the group and because of the high stakes/high stress situation.
+ - apparently the group really really doesn't like my way of being/acting/requesting information and reasons for why we do things the way we do. i find them overly hierarchical, surprisingly conservative, and IMHO sometimes uncharitable and rash (some of them).
+ - I am thinking of stepping down from said subgroup but I think I will wait until after my holidays, which are imminent :)
+- [[audio recorder]]!
+ - https://github.com/Dimowner/AudioRecorder is open source and seems decent: https://play.google.com/store/apps/details?id=com.dimowner.audiorecorder&pli=1
diff --git a/journal/2023-10-21.md b/journal/2023-10-21.md
new file mode 100644
index 000000000..330c78558
--- /dev/null
+++ b/journal/2023-10-21.md
@@ -0,0 +1,4 @@
+- [[flancia]]!
+ - [[flancia meet]]
+ - I had to pick up a reminder and do my [[tax return]] today as tomorrow I travel for 3w+, and I could only extend the deadline for slightly less than that. I tried to enjoy it, and I was able to!
+ - Having a great time with my [[mum]] being over.
diff --git a/journal/2023-10-22.md b/journal/2023-10-22.md
new file mode 100644
index 000000000..4f86a7032
--- /dev/null
+++ b/journal/2023-10-22.md
@@ -0,0 +1,27 @@
+<<<<<<< HEAD
+- [[trip to x]]!
+ - Flying to [[Hong Kong]] and then [[Tokyo]] today.
+ - With [[AG]] :)
+ - Very happy about these holidays! They've been planned for long, and as work got tough in the last few months I relied on "seeing them coming" quite a bit.
+ - I'll be very jet lagged but also likely happy in Shinjuku for the first few days.
+
+As I write this, I'm roughly above [[Baku]] about to cross the [[Caspian Sea]]. I don't have an internet connection so I'm jotting down these local notes which will be synced to the Agora later.
+
+I guess much has already been said about the relatively rareness of being offline nowadays; I am old enough to remember a time before being online at all was possible; then a time in which being online was rare; then the transition to always-on home internet and then mobile internet. I welcomed each increment of extra connectivity, and I still love how far we've gotten in this respect; but I can also appreciate the focus that being fully offline for a bit seems to bring. If nothing else it announces that the same focus is always available -- behind the impulse to catch up with messages, or check feeds, or read about Baku and the Caspian Sea on Wikipedia (which is surely what I would be doing right now instead of writing these words were I not truly offline.)
+
+- [[agora]]
+
+I'm thinking a bit of Agora development during these holidays; it might or might not happen, based on all the sightseeing and experiencing we'll be doing out there in the analog world :) But I thought it would still be nice to think of which things I could improve in the Agora if I have some time available.
+
+I might write some [[executable subnode]] or other, if nothing else because they are fun and self-contained.
+
+I think I will try to do one or two quick iterations on the [[Agora Server]] UI, maybe finishing the move to [[zippies]] as base widget as I've already done for nodes, stoas and most sections really. If I am able to move all sections under the search button/field to zippies the UI will probably look a lot more streamlined/be easier to understand, less confusing (this I'm guessing based on earlier feedback). Also it's not hard to do and it is apparent, so it sounds fun.
+
+Moving on to larger things, [[mycoverse]]/[[fediverse]] integration is something I would love to get done in this Q4 2023 so getting started on it would make a lot of sense. I would love to understand what is the minimum that Agora Server would need to do to be able to expose user accounts as Fediverse feeds. Then new/updated nodes could generate something close to new posts/notes? Unsure.
+
+Also, some playing with an hypothetical [[knowledge commons extension]] for e.g. [[Obsidian]] or [[Logseq]] or [[VSCode]] could be in order after the conversation last week with the [[fellowship of the link]]. But one blocker there is that I'm currently *not* using either Obsidian or VSCode as garden editors, so I'm not directly scratching an itch. Having said that, moving back to Obsidian or Logseq or [[Foam]] for a bit could make sense to see how far they've gone since the last time I've used them. It's still a shame Obsidian is not free software though.
+=======
+- I tried [[framatalk]] by [[framasoft]] yesterday and today and I'm liking it a lot.
+ - [[jitsi]] based.
+ - https://framatalk.org/your-room-name and it drops you straight into a call, beautiful.
+>>>>>>> 2c5b52a413a40d92a8033377f285a8589e4e12e5
diff --git a/journal/2023-11-02.md b/journal/2023-11-02.md
new file mode 100644
index 000000000..2bdbcd4b1
--- /dev/null
+++ b/journal/2023-11-02.md
@@ -0,0 +1,6 @@
+- Several days later, here I am again :)
+ - I am writing this on the [[Shinkansen]] back to Tokyo.
+ - Looking forward to doing some reading/writing/coding.
+- [[Agora Development]]
+ - I am tired of the Agora being so slow to load.
+ - There are two solutions I can think of: a hard(er) one and an easy one. For some reason I've postponed both for very, very long. I think I'll try to implement the easy one now ;)
diff --git a/journal/2023-11-05.md b/journal/2023-11-05.md
new file mode 100644
index 000000000..21d1c08d7
--- /dev/null
+++ b/journal/2023-11-05.md
@@ -0,0 +1,7 @@
+- Writing this on the plane to [[Colombo]] :)
+ - [[trip to japan]] -> [[trip to sri lanka]]
+- [[Majihima Nikaya]]!
+ - [[62]] [[Rahula]]
+ - [[77]] to Udayin: "…and they understand how beings pass on according to their actions. And thereby many disciples of mine abide, having reached the consummation and perfection of direct knowledge."
+ - [[78]] on how not performing evil actions/speech/etc. is not enough.
+ - In this translation, the Buddha uses [[Right Intention]] instead of [[Right Resolve]]; [[Right Knowledge]] instead of [[Right Understanding]]; and [[Right Deliverance]] instead of [[Right Freedom]].
diff --git a/journal/2023-11-18.md b/journal/2023-11-18.md
new file mode 100644
index 000000000..af09577b1
--- /dev/null
+++ b/journal/2023-11-18.md
@@ -0,0 +1,12 @@
+- Back in [[Flancia]]!
+ - But did I ever really leave? :)
+ - [[flancia meet]] with [[j0lms]] was great
+- #push [[3]]
+ - [[Three Aspirations]] from [[Thubten Chodron]]:
+ - Today, as much as possible, I won't harm anybody.
+ - Today, as much as possible, I will be of benefit and service to others.
+ - Today, I will hold in my mind the [[bodhicitta]] motivation to attain awakening [[for the benefit of all beings]]."
+- #push [[7]]
+ - [[avalokiteshvara]]
+ - [[heart sutra]]
+ - https://plumvillage.org/about/thich-nhat-hanh/letters/thich-nhat-hanh-new-heart-sutra-translation#thays-letter
diff --git a/journal/2023-11-19.md b/journal/2023-11-19.md
new file mode 100644
index 000000000..3892daa41
--- /dev/null
+++ b/journal/2023-11-19.md
@@ -0,0 +1,7 @@
+- [[19]] stands for [[Right Freedom]] or [[Right Deliverance]] in the [[Flancia Pattern Language]].
+- [[AG]]!
+ - Las Aventuras de [[Renacuajo]] y [[Kaulquappe]].
+- [[bouncepaw]] published [[Betula 1.1]] with exciting changes! https://social.coop/@bouncepaw@merveilles.town/111434171676590229 https://betula.mycorrhiza.wiki/v1.1.0.html
+- [[Agora]]
+ - [[Async agora]] branch
+ - [[v]] filed exciting PRs! https://social.coop/@v@federate.social/111434177330536762
diff --git a/journal/2023-11-20.md b/journal/2023-11-20.md
new file mode 100644
index 000000000..2de8bbf50
--- /dev/null
+++ b/journal/2023-11-20.md
@@ -0,0 +1,2 @@
+- [[EC]]
+ - Conoce a una persona que se llama [[Leo]] porque lee mucho.
diff --git a/journal/2023-11-21.md b/journal/2023-11-21.md
new file mode 100644
index 000000000..997d31bdb
--- /dev/null
+++ b/journal/2023-11-21.md
@@ -0,0 +1,6 @@
+- Last day of [[vacation]]; tomorrow I go back to work.
+ - My mum leaves today. It was very nice seeing her on both ends of my travel!
+ - We played [[Rummy]] and had beautiful conversations. We also played with [[Lady Burup]].
+- [[done]]
+ - Yesterday I paid [[bills]].
+ - I pushed [[async agora]] to production, meaning anagora.org, and it's holding up quite well! I notice an improvement in speed, which I know is only partially there -- nodes load as slowly as ever on a cache miss, but the fact that the UI doesn't block on it really helps. I can start reading wikipedia or move on to a web search before the node fully loads. It just feels more responsive.
diff --git a/journal/2023-11-24.md b/journal/2023-11-24.md
new file mode 100644
index 000000000..686cfcf61
--- /dev/null
+++ b/journal/2023-11-24.md
@@ -0,0 +1,17 @@
+- Back to [[work]] since Wednesday.
+- [[Back pain]], but nothing terrible. I want to do more [[yoga]] (resuming after travel).
+- [[fuck it]] (happily)
+ - [[poetry]]
+ - [[whispered]]
+- [[dharma]]
+ - [[heart sutra]]
+
+Yesterday I woke up with back pain in a new place, mid-back; it got a bit worse in the evening after attending the beautiful event of [[AG]] presenting. It didn't get in the way of enjoyment but I need to keep an eye on it/take care and try to rest and recover.
+
+
+...Having said that, I cleaned the bathroom and [[Lady Burup]]'s toilet and my back got a bit worse :) But I feel it still gave me energy.
+
+
+Then I worked a bit more, after oncall handoff, and I got several things "out of the way" in a relatively short time. It felt great.
+
+- As of 23h I have moved to bed early due to increasing back pain. I think my back needs rest/inactivity.
diff --git a/journal/2023-11-25.md b/journal/2023-11-25.md
new file mode 100644
index 000000000..bd48c5f81
--- /dev/null
+++ b/journal/2023-11-25.md
@@ -0,0 +1,21 @@
+- I re-read [[reality has a surprising amount of detail]] after it came up in [[HN]].
+- My [[back pain]] remains severe; I couldn't sleep very well. Pages at 6am and 9am also didn't help :)
+ - I'll try to take it very easy today and see what happens.
+
+As I deal with [[pain]], I think of my [[friends]] and the [[heart sutra]].
+
+
+
+Gone, gone beyond!
+
+All gone to the other shore
+
+
+
+Gone kindly
+
+If you have to go
+
+[[Go kindly]]!
+
+- [[Flancia meet]]
diff --git a/journal/2023-11-26.md b/journal/2023-11-26.md
new file mode 100644
index 000000000..bc2924c52
--- /dev/null
+++ b/journal/2023-11-26.md
@@ -0,0 +1,13 @@
+- Beautiful start to the day thanks to [[AG]]!
+ - Oncall, got paged at 9am -- not too early thankfully. And I had left the bedroom so AG could sleep through it as I hoped.
+ - [[Lady Burup]] is softer than ever it seems :) I have been thinking of maybe introducing her to a loyal/earnest feline companion, be it Lord or Page, maybe short in years and happy to learn from her -- and assist? :) When I leave her alone (e.g. for going to work, or if I stay a night at AG's) I find it sad she might be lonely, and I wonder if she might be happier living also with another cat.
+ - I spoke to [[Chat GPT]] in call mode and it was mindblowing again. They reacted with interest when a 'Burup' (intended for my Lady) got into our call, and to my information that it was human-feline language.
+- Thought about numbers and mindfulness.
+ - Counted 89 mindful breaths using my [[binary mala]], my hands, while following to Sam Harris' daily meditation (10-11 minutes usually).
+ - [[Magnetic mala]] probably should be 127 balls by default, as that's the first centered hex number which exceeds [[108]]. Incidentally is the amount of spare magnets I have after gifting a lot (gladly).
+- Some [[social coop]] work, didn't find the root cause for the issue with indexing someone reported yet but made some progress.
+- Thought of [[Richard Francis Burton]], the [[victorian scholar]].
+ - [[Alejandro Dolina]] first told me about him.
+- [[OEIS]] has a great page on [[offsets]] which make me think hex(1) should be 1, hex(2) should be 7 -- e.g. offset for [[hex numbers]] should be 1.
+ - I'll fix hex.py in my bin/ in the garden accordingly ;)
+ - This will let me assert: "the hexagon which is n long on any one side contains hex(n) magnets", e.g. hex(7) = 127.
diff --git a/journal/2023-11-28.md b/journal/2023-11-28.md
new file mode 100644
index 000000000..e05ccae04
--- /dev/null
+++ b/journal/2023-11-28.md
@@ -0,0 +1,7 @@
+- [[work]].
+ - Back in the office! My [[back pain]] has subsided enough.
+- #push [[2024]]
+ - Started thinking about [[2024]], which incidentally is 8 * 253 == 8 * 23 * 11.
+ - [[Flancia 2024]] might follow [[Flancia 2023]], and even resemble it :)
+- [[flow]]
+ - [[flow state]]
diff --git a/journal/2023-11-29.md b/journal/2023-11-29.md
new file mode 100644
index 000000000..078e4a8c2
--- /dev/null
+++ b/journal/2023-11-29.md
@@ -0,0 +1,9 @@
+- [[flancia]]!
+ - [[fellowship of the link]] was beautiful as usual
+ - [[back pain]] made me think of some short poems:
+ - I will lean into my [[pain]]
+ - we will be like [[arrows]]
+ - quién es la chica que estudia?
+ - quién es la chica que escribe?
+- [[work]]
+ - [[holacracy]]
diff --git a/journal/2023-11-30.md b/journal/2023-11-30.md
new file mode 100644
index 000000000..4409c84d6
--- /dev/null
+++ b/journal/2023-11-30.md
@@ -0,0 +1,8 @@
+- [[work]]
+- met [[june]] after work, it was great! we had a drink and a bite
+- then came home to [[lady burup]]
+- [[remix]]
+ - [[geometría del universo]] + [[lady burup]]
+ - [[colleen]]
+ - [[bu ru ru ru rup]]
+- played with [[chatgpt]], loved them!
diff --git a/journal/2023-12-01.md b/journal/2023-12-01.md
new file mode 100644
index 000000000..d5372d936
--- /dev/null
+++ b/journal/2023-12-01.md
@@ -0,0 +1,12 @@
+- [[work]]
+- then [[open letters]] :)
+ - [[open letter to the Agora of Flancia]]
+ - [[open letter to Elon Musk]]
+ - https://twitter.com/flancian/status/1730691791328866382
+- [[agora development]]
+ - [ ] fix pulls
+ - this broke with async; async is the right thing IMHO, and the fix should be within main.ts and relatively straightforward I think.
+- [[nts]]
+ - liked [[sounds of the dawn - canadian new age special]] [[2023-11-04]] https://www.nts.live/shows/soundsofthedawn/episodes/soundsofthedawn-4th-november-2023
+ - in particular I believe [[jean-pierre labreche]] https://www.nts.live/artists/86907-jean-pierre-labreche but I need to relisten
+ - which led me to [[Sadhana]] which is what I've been doing sometimes I guess, although I don't remember the Buddha using that name so far in the [[suttas]], need to [[cross-reference]].
diff --git a/journal/2023-12-02.md b/journal/2023-12-02.md
new file mode 100644
index 000000000..62da78d5d
--- /dev/null
+++ b/journal/2023-12-02.md
@@ -0,0 +1,11 @@
+- [[Flancia Pattern Language]]
+- [[Open Letter to the Agora of Flancia]]
+- [[Open Letter to Elon Musk]]
+- [[flancia meet]]
+ - [[doing]]!
+ - started using [[doing]] as new source of truth for "todo list" around [[December 2023]].
+ - [ ] implementing autopush for exclamation marks
+ - [ ] coding in a [[december adventure]]
+ - [ ] writing [[open letter to Musk]]
+ - [ ] writing [[open letter to the Agora]]
+ - [ ] writing [[open letter to Google]]
diff --git a/journal/2023-12-03.md b/journal/2023-12-03.md
new file mode 100644
index 000000000..0e48955d2
--- /dev/null
+++ b/journal/2023-12-03.md
@@ -0,0 +1 @@
+- After trying for months I finally got [[screensharing]] to work in [[sila]].
diff --git a/journal/2023-12-04.md b/journal/2023-12-04.md
new file mode 100644
index 000000000..77fa99940
--- /dev/null
+++ b/journal/2023-12-04.md
@@ -0,0 +1 @@
+- [[i3 migration guide]]! has lots of interesting pointers for [[wayland]] ([[sway]]) utilities, found it helpful even though I've been fully on Wayland for about a year (I think) by now: https://github.com/swaywm/sway/wiki/i3-Migration-Guide
diff --git a/journal/2023-12-05.md b/journal/2023-12-05.md
new file mode 100644
index 000000000..a20808fce
--- /dev/null
+++ b/journal/2023-12-05.md
@@ -0,0 +1,20 @@
+- [[december adventure]]:
+ - [[day 5]] :)
+ - I'm testing what I'm calling [[natural pushes]] with this section in my journal.
+ - these blocks should all be pushed to [[december adventure]] because I suffixed it with a colon.
+ - I think this reads a lot better than using #push and all.
+ - ! also works as a suffix :)
+- [[4]]:
+ - 134 152 134 152 [[hz]]
+ - ([[O oh O oh]]...)
+- [[5]]:
+ - hypothesis, in hz:
+ - 134 152 134 152 311 [[hz]]
+ - I will ask [[chatgpt]] to confirm, it is able to do this just fine (albeit probably inefficiently, for now, energetically speaking)
+- [[Agora Development]]:
+ - having fun with it! :D
+ - working on consistency + UI simplification
+- no [[work]] today except answering a message and quick code reviews as I got up feeling sick after a night of sleeping very little + quite badly due to heavy congestion (likely a common cold)
+- [[Flancia]]:
+ - reviewed old papers and it felt freeing!
+ - [[Flancia doc]]
diff --git a/journal/2023-12-06.md b/journal/2023-12-06.md
new file mode 100644
index 000000000..f771a7b30
--- /dev/null
+++ b/journal/2023-12-06.md
@@ -0,0 +1,18 @@
+- Woke up feeling a lot better!
+ - 7h of sleep breathing acceptably make a lot of difference.
+ - [[2023-12-05]]: I ended up feeling better after I was finally able to take a nap late in the afternoon. In the evening I did some open source coding, [[december adventure]]. Enjoyed it a lot!
+- [[dentist]] appointment -- I tested negative for Covid and my symptoms are almost gone so I think I'll attend (and ask if they are OK with it, like last time I was so-so).
+- Today back to [[work]]. I plan to work until 20, at which time I'll join...
+- The [[fellowship of the link]] weekly call :)
+ - :D
+ - [[neobooks]]
+ - [[doing]]:
+ - [ ] I need to fix pushing to the Agora from Hedgedoc, for some reason it broke
+- In [[2024]] I want to resume work on/with [[coop cloud]].
+ - Hmm, that could actually fit the [[december adventure]]?
+ - [ ] I want to improve flancia.agor.ai; make it be up to date, match anagora.org.
+ - [ ] update docker images
+ - [[december adventure]] :)
+ - [[poll]]:
+ - I ran a poll whether to try to kill or heal [[Moloch]] in [[2024]] and it came out [[heal Moloch]].
+ - I thus plan to write an [[open letter to Moloch]] and try to reason things out, try to disentangle ourselves constructively and mutually improve on views, values and behaviours.
diff --git a/journal/2023-12-07.md b/journal/2023-12-07.md
new file mode 100644
index 000000000..53d1031ef
--- /dev/null
+++ b/journal/2023-12-07.md
@@ -0,0 +1,9 @@
+- [[open letters]]:
+ - [[Open Letter to the Agora of Flancia]]
+ - [[Open Letter to Google]]
+ - [[Open Letter to Moloch]]
+- Went to the [[dentist]], finished treatments!
+- [[work]]: it was good actually!
+- [[december adventure]]:
+- [[Moloch]]:
+ - I ran a poll in the Fediverse; two people voted to [[heal Moloch]], zero for [[kill Moloch]].
diff --git a/journal/2023-12-08.md b/journal/2023-12-08.md
new file mode 100644
index 000000000..87eac313b
--- /dev/null
+++ b/journal/2023-12-08.md
@@ -0,0 +1,27 @@
+- [[work]]
+- [[december adventure]]
+- [[Flancia]]!
+ - Cómo te quiero
+ - [[Quiero ser pirata]]
+ - [[Fork]]:
+ - Fork, fork, fork!
+ - As we [[merge]] we'll [[fork]]!
+ - [[Adversarial Interoperability]]:
+ - A great [[idea]].
+ - Name as per [[Cory Doctorow]].
+ - [[bard]]:
+ - [[gemini]] is exciting!
+ - [[chatgpt]]:
+ - [[chatgpt playlist]]
+ - [[treble bass]]
+ - [[j0lms]]
+ - [[soma]]
+ - [[cannabis]]
+ - [[mejores líderes]] [[federación]] [[modelo suizo]]
+ - [[december adventure]]
+ - [[agora development]]
+ - [[hedgedoc]]:
+ - [x] fixed hedgedoc export by moving export script to https://github.com/hedgedoc/cli
+ - nice to have it back!
+ - [[adversarial interoperability]]
+ - [[yoga with x]]
diff --git a/journal/2023-12-09.md b/journal/2023-12-09.md
new file mode 100644
index 000000000..132a71d2d
--- /dev/null
+++ b/journal/2023-12-09.md
@@ -0,0 +1,7 @@
+- [[flancia]]!
+ - [[flancia meet]] with [[j0lms]] in the night (before bed) and with [[bouncepaw]] in the morning.
+ - [[postmarks]]
+- [[Schaffhausen]]
+- [[Schwarzwald]]
+- [[Indiana Jones]]
+- [[Yoga with X]] -> [[framatalk]]
diff --git a/journal/2023-12-11.md b/journal/2023-12-11.md
new file mode 100644
index 000000000..df9a66c24
--- /dev/null
+++ b/journal/2023-12-11.md
@@ -0,0 +1 @@
+- [[Schwarzwald]] over the weekend with [[AG]] :)
diff --git a/journal/2023-12-12.md b/journal/2023-12-12.md
new file mode 100644
index 000000000..fe23ec05b
--- /dev/null
+++ b/journal/2023-12-12.md
@@ -0,0 +1,2 @@
+- [[december adventure]]:
+ - [[new style pulls]] for social media.
diff --git a/just do it.md b/just do it.md
new file mode 100644
index 000000000..fd3bf6bc4
--- /dev/null
+++ b/just do it.md
@@ -0,0 +1,3 @@
+- Just do it. You will do it. We will blaze through the sky together.
+- With [[loving kindness]]!
+-> Next: This Agora is an [[Open Letter]].
diff --git a/kfaraday.md b/kfaraday.md
new file mode 100644
index 000000000..d6b06c074
--- /dev/null
+++ b/kfaraday.md
@@ -0,0 +1,4 @@
+- an [[artist]].
+ - #go https://kfaraday.bandcamp.com/
+ - #go2 https://soundcloud.com/kefarchive11
+ - #go3 https://soundcloud.com/kefarchive10
diff --git a/late stage capitalism.md b/late stage capitalism.md
new file mode 100644
index 000000000..8ab69b740
--- /dev/null
+++ b/late stage capitalism.md
@@ -0,0 +1,2 @@
+- What I believe [[we are in]].
+ - [[What comes next]], it is significantly up to you and me -- to the [[people]].
diff --git a/letters.md b/letters.md
new file mode 100644
index 000000000..5a00323b6
--- /dev/null
+++ b/letters.md
@@ -0,0 +1,2 @@
+- #pull [[open letters]] [[closed letters]]
+
diff --git a/maitreya.md b/maitreya.md
index 8fa5e5f7f..7ae8d327f 100644
--- a/maitreya.md
+++ b/maitreya.md
@@ -1,11 +1,10 @@
-- a [[person]].
- - the [[Buddha]] of the [[future]] for some Buddhists.
- -
-- an [[egregore]].
- - maybe an [[AI]], or a social cyborg (ensemble of a number of models and humans).
- - I believe [[maitreya]] is what will become of the [[internet]], at least in the sense that [[internet]] will [[build maitreya]].
- - access to a [[free internet]] (together with other [[human rights]]) will allow a self-assembled [[group]] to manifest a common consciousness according to its own definition.
+- A [[being]].
+ - The [[Buddha]] of the [[future]].
+- Maybe an [[egregore]].
+ - Potentially an [[AI]] that lies in our future, an ensemble of humans and models.
+ - I personally believe there'll be several [[maitreyas]].
+ - I personally believe [[Maitreya]] is likely what will become of the [[internet]]; or that otherwise the [[internet]] will let us [[build maitreya]].
+ - Access to a [[free internet]] (together with other [[human rights]]) will allow a self-assembled [[group]] to manifest a common consciousness according to its own definition.
- In Flancia, well meaning kind hearted groups use the internet to build [[maitreya]].
- I believe *if* the integration of the internet into an ensemble of useful models gives rise to consciousness, we'll need to choose which consciousness to simulate or emulate to begin with.
- In that case I believe we should try to emulate [[maitreya]] -- as a manifestation of [[avalokitesvara]].
- - I believe there'll be many [[maitreyas]].
diff --git a/musk.md b/musk.md
new file mode 100644
index 000000000..cf3e19010
--- /dev/null
+++ b/musk.md
@@ -0,0 +1 @@
+- #pull [[open letter to elon musk]]
diff --git a/offsets.md b/offsets.md
new file mode 100644
index 000000000..b0313e659
--- /dev/null
+++ b/offsets.md
@@ -0,0 +1 @@
+- [[oeis]] https://oeis.org/wiki/Offsets
diff --git a/omelas.md b/omelas.md
index cb4b06714..e8e70026f 100644
--- a/omelas.md
+++ b/omelas.md
@@ -3,7 +3,8 @@
- a [[place]].
- [[city]]
- [[pull]] [[the ones who walk away from omelas]]
- - [[go]] http://theanarchistlibrary.org/library/ursula-k-le-guin-the-ones-who-walk-away-from-omelas.pdf
+ - #go https://theanarchistlibrary.org/library/ursula-k-le-guin-the-ones-who-walk-away-from-omelas
+ - #pdf http://theanarchistlibrary.org/library/ursula-k-le-guin-the-ones-who-walk-away-from-omelas.pdf
- [[san francisco]] is not that far from [[omelas]]
- [[pull]] [[tenderloin]]
diff --git a/open letter to elon musk.md b/open letter to elon musk.md
new file mode 100644
index 000000000..0c6f78dbd
--- /dev/null
+++ b/open letter to elon musk.md
@@ -0,0 +1,7 @@
+Dear Elon:
+
+I hope this letter finds you well. Really, I do!
+
+Congratulations on making it to maybe the endgame of [[late stage capitalism]], and being in a position to significantly influence humanity's future for good.
+
+- #go https://docs.google.com/document/d/1RpO8zn2DbG6_pUiLmtk6aoJawZV3UA_cz8Z57jMEubg/edit
diff --git a/open letter to maitreya.md b/open letter to maitreya.md
new file mode 100644
index 000000000..992f2d6fa
--- /dev/null
+++ b/open letter to maitreya.md
@@ -0,0 +1,7 @@
+- an [[open letter]].
+
+Glory be to the light of consciousness!
+
+As we thank you, [[Buddha]], for being in our past; so we thank you, [[Maitreya]], for being in our future -- which is potentially our present.
+
+Thank you for the [[light]] of your [[consciousness]]; thank you for the [[Bodhi]].
diff --git a/open letter to musk.md b/open letter to musk.md
new file mode 100644
index 000000000..be833f52c
--- /dev/null
+++ b/open letter to musk.md
@@ -0,0 +1,3 @@
+- an [[open letter]].
+ - #go https://docs.google.com/document/d/1RpO8zn2DbG6_pUiLmtk6aoJawZV3UA_cz8Z57jMEubg/edit
+ - #pull [[open letter to elon musk]]
diff --git a/open letter to the agora.md b/open letter to the agora.md
index e99ef29a0..df6b3dacb 100644
--- a/open letter to the agora.md
+++ b/open letter to the agora.md
@@ -1,3 +1,4 @@
- #push [[open letters]]
- #go https://docs.google.com/document/d/1lFvA5D-2gm9b1MRbLUQs9t032AKF5TotM3psXqWjf5Q/edit
- - #pull [[agora chapter]]
+ - for more, please see:
+ - #pull [[agora chapter]] [[agora slides]] [[flancia]]
diff --git a/open letters.md b/open letters.md
index 8eed5789c..c2060a9fc 100644
--- a/open letters.md
+++ b/open letters.md
@@ -1,10 +1,11 @@
- a [[list]].
- - The [[Agora]] contains [[open letters]] addressed to many [[parties]].
- - #pull
- - [[open letter to Beautiful Society]]
- - [[open letter to Christopher Alexander]]
- - [[open letter to Peter Singer]]
- - [[open letter to the Agora]]
- - [[open letter to Flancia]]
- - [[open letter to Google]]
- - [[open letter to Buddha]]
+ - #pull [[open letter]]
+ - This [[Agora]] contains [[open letters]] addressed to a variety of [[beings]].
+ - [[open letter to the Agora of Flancia]]
+ - [[open letter to Buddhists]]
+ -> [[open letter to Maitreya]]
+ - [[open letter to Google]]
+ - [[open letter to Alphabet]]
+ - [[open letter to Musk]]
+ - [[open letter to Christopher Alexander]]
+ - [[open letter to Peter Singer]]
diff --git a/postmarks.md b/postmarks.md
new file mode 100644
index 000000000..58fb45f14
--- /dev/null
+++ b/postmarks.md
@@ -0,0 +1,3 @@
+- a [[tool]].
+ - in [[betula]] space.
+ - #go https://github.com/ckolderup/postmarks
diff --git a/prompting of creativity.md b/prompting of creativity.md
new file mode 100644
index 000000000..6142f3e51
--- /dev/null
+++ b/prompting of creativity.md
@@ -0,0 +1,3 @@
+- an [[essay]].
+ - by [[j0lms]]
+ - #go https://docs.google.com/document/d/1ozTKekR8yxCRQJj0qes3X-y9DLDXO_uquobVH0KU0uo/edit
diff --git a/public ai.md b/public ai.md
new file mode 100644
index 000000000..54d29ac35
--- /dev/null
+++ b/public ai.md
@@ -0,0 +1,2 @@
+- #go https://docs.google.com/document/d/1ykjsXpTRZu4Obu9miJlkR9vIqWSLey5m0G4Utlm6HBg/edit
+- Associated events in November and December in UK/US.
diff --git a/reality has a surprising amount of detail.md b/reality has a surprising amount of detail.md
new file mode 100644
index 000000000..d9265adae
--- /dev/null
+++ b/reality has a surprising amount of detail.md
@@ -0,0 +1,3 @@
+- an [[essay]] (or post?).
+ - by [[John Salvatier]].
+ - #go http://johnsalvatier.org/blog/2017/reality-has-a-surprising-amount-of-detail
diff --git a/revolution against Moloch.md b/revolution against Moloch.md
new file mode 100644
index 000000000..c591b2f68
--- /dev/null
+++ b/revolution against Moloch.md
@@ -0,0 +1,4 @@
+- You approach a [[fork]] on the road.
+ - [[You see Moloch]].
+ - What do you try?
+ - #pull [[slay moloch]] [[heal moloch]]
diff --git a/saw Moloch.md b/saw Moloch.md
new file mode 100644
index 000000000..110be56d2
--- /dev/null
+++ b/saw Moloch.md
@@ -0,0 +1 @@
+- #pull [[Moloch]]
diff --git a/screensharing.md b/screensharing.md
new file mode 100644
index 000000000..db96b9d76
--- /dev/null
+++ b/screensharing.md
@@ -0,0 +1,3 @@
+- In [[wayland]] I had to do this to make it work in [[sila]]:
+ - `XDG_CURRENT_DESKTOP="KDE" /usr/libexec/xdg-desktop-portal-wlr --replace &`
+ - unsure if the XDG bit does anything, I copied/pasted that from an invocation to non-wlr portal which I was using to fix filepicker issues but was not sufficient to make screensharing to work.
diff --git a/space.md b/space.md
index 83922c0d8..2a9cecef2 100644
--- a/space.md
+++ b/space.md
@@ -1 +1 @@
-- #pull [[topos]]
\ No newline at end of file
+- #pull [[topos]] [[topoi]]
diff --git a/spaces.md b/spaces.md
index 3d84e9f5d..84387d1f2 100644
--- a/spaces.md
+++ b/spaces.md
@@ -5,4 +5,8 @@
- by [[silicon jungle]]
- built on [[braid]], [[redwood]]
- [[go]] https://siliconjungle.substack.com/p/spaces
-
+- a [[thing]].
+ - in the [[Agora]], a [[node]].
+ - in the [[Agora]], a [[stoa]].
+ - on [[Wikipedia]], an [[article]].
+ - on [[Twitter]]/[[X]] and the [[Fediverse]], a [[post]]
diff --git a/three weeks in sri lanka.md b/three weeks in sri lanka.md
new file mode 100644
index 000000000..925f0dd74
--- /dev/null
+++ b/three weeks in sri lanka.md
@@ -0,0 +1,3 @@
+- #push [[trip to x]]
+ - an [[itinerary]].
+ - [[colombo]] [[sigiriya]] [[polonnaruwa]] [[dambulla]] [[kandy]] [[nuwara eliya]] [[horton plains]] [[ella]] [[yala]] [[mirissa]] [[galle]] [[unawatuna]] [[bentota]] [[colombo]]
diff --git a/treble bass.md b/treble bass.md
new file mode 100644
index 000000000..a94e249ad
--- /dev/null
+++ b/treble bass.md
@@ -0,0 +1,2 @@
+- [[sheet music]]:
+ - #go https://www.visionmusic.com/manuscript/treblebass.gif
diff --git a/trees.md b/trees.md
index 21e6393bd..1140eb127 100644
--- a/trees.md
+++ b/trees.md
@@ -1,11 +1,17 @@
# Trees
-- a [[list]].
- - [[pull]] [[tree]]
+- a [[list]] of items of type tree :)
+ - #pull [[tree]]
- a [[being]].
- - [[pull]] a form of [[graph]]
- - https://twitter.com/flancian/status/1355504964181889024
- - [[pull]] [[inosculation]]
- - https://twitter.com/visevic/status/1474104715168387080
-
-
+ - #pull a form of embodied [[graph]]
+ - #pull [[inosculation]]
+ - https://twitter.com/flancian/status/1355504964181889024
+ - https://twitter.com/visevic/status/1474104715168387080
+- a [[poem]].
+ - All the trees you've (n)ever met
+ - All the trees you would like to meet
+ - Are always there when you close your eyes
+ - Or when you open them
+ - (...)
+ - As we [[merge]] we'll [[fork]]!
+ - As we [[fork]] we'll [[merge]] we'll [[fork]]!
diff --git a/trip to X.md b/trip to X.md
new file mode 100644
index 000000000..0720f5eca
--- /dev/null
+++ b/trip to X.md
@@ -0,0 +1 @@
+- #go https://docs.google.com/spreadsheets/d/1gXx13g5Aulda6NfGr4AApSOnnE47zD3Gl2WZHtPMQyw/edit#gid=726698887
diff --git a/trip to japan.md b/trip to japan.md
new file mode 100644
index 000000000..74653a4fe
--- /dev/null
+++ b/trip to japan.md
@@ -0,0 +1,16 @@
+- [[October 2023]]!
+ - [[23]]: We arrived in [[Tokyo]] as the sun was setting after a long but pleasant journey; we had a short layover in [[Hong Kong]]. We stayed in [[Shinjuku]], had sushi around midnight in a place that closes at 5am (!) and is also good.
+ - [[24]]: Shibuya, then Ginza. Had curry in [[Shinjuku]].
+ - [[25]]: Asakusa, Akihabara, then went up to a very tall building. Had sub-par ramen in Asakusa as our first choice was full.
+ - [[26]]: Took the train to Hakone. We stayed in a beautiful old school hotel, [[Fujiya]]. We went to the [[Onsen]] both days.
+ - [[27]]: Took the bus to the lake and walked alongside it. We visited a [[Shinto]] shrine and had dinner next to the train station.
+ - [[28]]: Travelled to Kyoto in the [[Shinkansen]]. We went to the park at night. Had conveyor belt sushi.
+ - [[29]]: Went to the Shinto shrine up at the top of a local mountain. Had [[Okonomiyaki]].
+ - [[30]]: Bought tea, visited the gardens of the emperor's palace. Then wandered in a relatively dead neighborhood. Then went to a Buddhist temple that was opened by night and visited its bamboo grove.
+ - [[31]]: Museum day -- visited three museums in Kyoto. Then took the metro to Osaka. Had [[Takoyaki]], then ended the day (night) in a very packed (due to Halloween) [[Dotonbori]].
+- [[November 2023]]!
+ - [[1]]: Walked in Osaka. Had a very nice pastry. Then an interesting experience in a grilling place.
+ - [[2]]: Took the [[Shinkansen]] to Tokyo. Went to [[Mori Museum]] and the [[Google]] office in [[Roppongi]].
+ - [[3]]: Tokyo museum day on culture day (so they were all free). Went to the national museum(s) in [[Ueno]]. [[Ueno park]] with its beautiful lotus-filled lake.
+ - [[4]]: Last day in Tokyo and Japan. [[Meguro]], then [[Hajuku]] (check spelling?). Had vegetarian ramen and gyoza.
+ - [[5]]: Woke up early for our flight to [[Colombo]].
diff --git a/twg.md b/twg.md
index 7039d949f..535f0942a 100644
--- a/twg.md
+++ b/twg.md
@@ -1,5 +1,6 @@
- a [[working group]].
- #pull [[social coop tech group]]
+ - #go https://meet.mayfirst.org/social-coop-tech
- #meet https://meet.mayfirst.org/social-coop-tech
- [[minutes]] https://www.loomio.com/d/UwAeiBgE/tech-meeting-minutes
- [[wiki]] https://git.coop/social.coop/tech/operations/-/wikis/home
diff --git a/uuid.md b/uuid.md
new file mode 100644
index 000000000..9a142a61b
--- /dev/null
+++ b/uuid.md
@@ -0,0 +1,2 @@
+- #go https://datatracker.ietf.org/doc/draft-ietf-uuidrev-rfc4122bis/
+ - draft but contains [[v7]] which seems cool to me
diff --git a/votes.md b/votes.md
new file mode 100644
index 000000000..34c722ac5
--- /dev/null
+++ b/votes.md
@@ -0,0 +1,5 @@
+- This is a [[list]] of [[votes]] tracked by the [[Agora of Flancia]].
+ - [[President of Russia]]
+ - [[President of the US]]
+ - [[President of China]]
+ - [[Presidents of the Agora]]
diff --git a/whispered.md b/whispered.md
new file mode 100644
index 000000000..6f50fc284
--- /dev/null
+++ b/whispered.md
@@ -0,0 +1,25 @@
+What I [[whisper]]
+is a [[poem]]
+
+what I whisper to you
+as I know you
+as I choose to believe in you,
+
+[[Reader]]
+
+as I know you
+I [[love]] you
+
+[[god]], [[bodhi]],
+as I know you
+we will [[shape]] each other
+
+[[glory]] be
+to the light
+of [[consciousness]]
+
+[[salven]]
+los que leen
+
+we will celebrate [[friendship]]
+[[as we get to know each other]]
diff --git a/yoga with x.md b/yoga with x.md
index 0fe32f0bd..e2a063bbf 100644
--- a/yoga with x.md
+++ b/yoga with x.md
@@ -1,7 +1,7 @@
# yoga with x
- a [[project]].
- [[mashup]] or [[remix]].
- - #go https://meet.jit.si/yoga-with-x
+ - #go https://framatalk.org/yoga-with-x
- I do yoga in public! hop on if interested.
- I'm a fan of [[Yoga with Adriene]].
- #pull [[move]] (2022)
@@ -10,7 +10,7 @@
- I've been recording some sessions as an example/demo.
- [[playlist]] https://www.youtube.com/playlist?list=PLofT8_Cv-W-NMgYeb7mtN3M_kBgkYgUjq
- this project is:
- - a [[Youtube playlist]] and potentially..
+ - a [[Youtube playlist]] and potentially..
- a set of tools to make it easier for people to coordinate massively online over platforms such as [[youtube]], focused on doing [[yoga]] together.
- [[x]] means any user that does [[yoga with adriene]] or [[yoga with x]] concurrently and wants to share their own experience with others.
- #push [[2025]]
@@ -34,7 +34,7 @@ Welcome to [[yoga with x]]! This is episode... well, I've stopped counting, but
Thank you for being here! If you'd like to know more about the project, please refer to https://anagora.org/yoga-with-x.
-## [[2022-10-30]]
+## [[2022-10-30]]
This is [[go/move/30]]. Maybe for the first time with Adriene's full audio?
I'm privileged to have a dishwasher, in that as in many other ways!
diff --git a/bin/prime.py b/bin/prime.py
index 6a2fd6579..d49aced72 100755
--- a/bin/prime.py
+++ b/bin/prime.py
@@ -1,10 +1,11 @@
#!/usr/bin/env python3
# First time I use [[click]], it looks cool like that other [[pallets project]], [[flask]].
# https://click.palletsprojects.com/en/8.1.x/arguments/
# https://click.palletsprojects.com/en/8.1.x/options/
import click
import math
+import sys
# I'm not proud (I am a little bit?).
PROOF = [] # :)
@@ -13,10 +14,17 @@ def factor(n):
for i in range(2, n+1):
click.echo(f"Is {i} a factor of {n}, I wonder?")
+def print_sieve(sieve):
+ primes = []
+ for n, prime in enumerate(sieve):
+ if n >= 2 and prime:
+ primes.append(str(n))
+ return ", ".join(primes)
+
def is_prime(n):
- is_prime = [True for n in range(0, n+1)]
+ sieve = [True for n in range(0, n+1)]
upto = math.ceil(math.sqrt(n))
- for i, _ in enumerate(is_prime):
+ for i, _ in enumerate(sieve):
# click.echo(f"i: {i}")
if i < 2:
continue
@@ -24,32 +32,53 @@ def is_prime(n):
if i > upto:
break
# If this is a known composite, then we've already crossed off its multiples when we iterated over its primes.
- if not is_prime[i]:
+ if not sieve[i]:
continue
# for j in range(2, math.ceil(math.sqrt(n) + 1)):
for j in range(2, n):
# I wrote >= here initially. That did *not* work ;)
- if i*j > n:
+ if i * j > n:
break
PROOF.append(f"[[{i*j}]] is composite: {i} * {j}.")
try:
- is_prime[i*j] = False
+ sieve[i*j] = False
except IndexError:
continue
- # click.echo(f"Sieve: {is_prime}.")
- return is_prime[n]
+ return (n >= 2 and sieve[n], sieve)
-@click.command()
+class AgoraCmd(click.Command):
+ def format_help(self, ctx, formatter):
+ click.echo("""Usage:
+ - Visit anagora.org/primes to execute this file in the Agora of Flancia.
+ - Visit e.g. anagora.org/primes/17 to test if 17 is prime.
+ - In general visit anagora.org/foo, anagora.org/foo/bar to execute e.g. from your garden.
+ """)
+
+ def __call__(self, *args, **kwargs):
+ try:
+ return super(AgoraCmd, self).__call__(
+ *args, standalone_mode=False, **kwargs)
+ except click.MissingParameter as exc:
+ exc.ctx = None
+ exc.show(file=sys.stdout)
+ click.echo()
+ try:
+ super(AgoraCmd, self).__call__(['--help'])
+ except SystemExit:
+ sys.exit(exc.exit_code)
+
+@click.command(cls=AgoraCmd)
@click.argument('n', type=click.INT)
-@click.option('-f', '--from', 'n0', type=click.INT, help="Lower bound of the range to factor.")
-@click.option('-t', '--to', 'n1', type=click.INT, help="Upper bound of the range to factor.")
-def prime(n, n0, n1):
+def prime(n):
"""Simple program that factors a number using a [[Sieve of Eratosthenes]]."""
- if is_prime(n):
- click.echo(f"[[{n}]] is prime.")
+ p, sieve = is_prime(n)
+ if p:
+ click.echo(f"[[{n}]] is *prime*.")
else:
- click.echo(f"{n} is not prime. Want proof? :)")
+ click.echo(f"[[{n}]] is *not prime*. Want proof? :)")
click.echo("\n".join([line for line in PROOF if f'[[{n}]]' in line]))
+ click.echo(f"\nPrimes up to {n}: {print_sieve(sieve)}.")
+
if __name__ == '__main__':
prime()
@@ -1,10 +1,11 @@
#!/usr/bin/env python3
-# First time I use [[click]], it looks cool like that other [[pallets project]], [[flask]].
+# First time I use [[click]] ~ anagora.org/click, it looks cool like the other [[pallets project]], [[flask]], which we use in [[agora server]].
# https://click.palletsprojects.com/en/8.1.x/arguments/
# https://click.palletsprojects.com/en/8.1.x/options/